#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class QueryRecord(object):

    def __init__(self):
        self._block_addr = None
        self._block_height = None
        self._corp_code = None
        self._corp_name = None
        self._notary_status = None
        self._opr_cert_name = None
        self._refuse_reason = None
        self._sign_order = None
        self._sign_time = None
        self._sign_type_code = None
        self._syn_time = None
        self._tx_hash_code = None

    @property
    def block_addr(self):
        return self._block_addr

    @block_addr.setter
    def block_addr(self, value):
        self._block_addr = value
    @property
    def block_height(self):
        return self._block_height

    @block_height.setter
    def block_height(self, value):
        self._block_height = value
    @property
    def corp_code(self):
        return self._corp_code

    @corp_code.setter
    def corp_code(self, value):
        self._corp_code = value
    @property
    def corp_name(self):
        return self._corp_name

    @corp_name.setter
    def corp_name(self, value):
        self._corp_name = value
    @property
    def notary_status(self):
        return self._notary_status

    @notary_status.setter
    def notary_status(self, value):
        self._notary_status = value
    @property
    def opr_cert_name(self):
        return self._opr_cert_name

    @opr_cert_name.setter
    def opr_cert_name(self, value):
        self._opr_cert_name = value
    @property
    def refuse_reason(self):
        return self._refuse_reason

    @refuse_reason.setter
    def refuse_reason(self, value):
        self._refuse_reason = value
    @property
    def sign_order(self):
        return self._sign_order

    @sign_order.setter
    def sign_order(self, value):
        self._sign_order = value
    @property
    def sign_time(self):
        return self._sign_time

    @sign_time.setter
    def sign_time(self, value):
        self._sign_time = value
    @property
    def sign_type_code(self):
        return self._sign_type_code

    @sign_type_code.setter
    def sign_type_code(self, value):
        self._sign_type_code = value
    @property
    def syn_time(self):
        return self._syn_time

    @syn_time.setter
    def syn_time(self, value):
        self._syn_time = value
    @property
    def tx_hash_code(self):
        return self._tx_hash_code

    @tx_hash_code.setter
    def tx_hash_code(self, value):
        self._tx_hash_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.block_addr:
            if hasattr(self.block_addr, 'to_alipay_dict'):
                params['block_addr'] = self.block_addr.to_alipay_dict()
            else:
                params['block_addr'] = self.block_addr
        if self.block_height:
            if hasattr(self.block_height, 'to_alipay_dict'):
                params['block_height'] = self.block_height.to_alipay_dict()
            else:
                params['block_height'] = self.block_height
        if self.corp_code:
            if hasattr(self.corp_code, 'to_alipay_dict'):
                params['corp_code'] = self.corp_code.to_alipay_dict()
            else:
                params['corp_code'] = self.corp_code
        if self.corp_name:
            if hasattr(self.corp_name, 'to_alipay_dict'):
                params['corp_name'] = self.corp_name.to_alipay_dict()
            else:
                params['corp_name'] = self.corp_name
        if self.notary_status:
            if hasattr(self.notary_status, 'to_alipay_dict'):
                params['notary_status'] = self.notary_status.to_alipay_dict()
            else:
                params['notary_status'] = self.notary_status
        if self.opr_cert_name:
            if hasattr(self.opr_cert_name, 'to_alipay_dict'):
                params['opr_cert_name'] = self.opr_cert_name.to_alipay_dict()
            else:
                params['opr_cert_name'] = self.opr_cert_name
        if self.refuse_reason:
            if hasattr(self.refuse_reason, 'to_alipay_dict'):
                params['refuse_reason'] = self.refuse_reason.to_alipay_dict()
            else:
                params['refuse_reason'] = self.refuse_reason
        if self.sign_order:
            if hasattr(self.sign_order, 'to_alipay_dict'):
                params['sign_order'] = self.sign_order.to_alipay_dict()
            else:
                params['sign_order'] = self.sign_order
        if self.sign_time:
            if hasattr(self.sign_time, 'to_alipay_dict'):
                params['sign_time'] = self.sign_time.to_alipay_dict()
            else:
                params['sign_time'] = self.sign_time
        if self.sign_type_code:
            if hasattr(self.sign_type_code, 'to_alipay_dict'):
                params['sign_type_code'] = self.sign_type_code.to_alipay_dict()
            else:
                params['sign_type_code'] = self.sign_type_code
        if self.syn_time:
            if hasattr(self.syn_time, 'to_alipay_dict'):
                params['syn_time'] = self.syn_time.to_alipay_dict()
            else:
                params['syn_time'] = self.syn_time
        if self.tx_hash_code:
            if hasattr(self.tx_hash_code, 'to_alipay_dict'):
                params['tx_hash_code'] = self.tx_hash_code.to_alipay_dict()
            else:
                params['tx_hash_code'] = self.tx_hash_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = QueryRecord()
        if 'block_addr' in d:
            o.block_addr = d['block_addr']
        if 'block_height' in d:
            o.block_height = d['block_height']
        if 'corp_code' in d:
            o.corp_code = d['corp_code']
        if 'corp_name' in d:
            o.corp_name = d['corp_name']
        if 'notary_status' in d:
            o.notary_status = d['notary_status']
        if 'opr_cert_name' in d:
            o.opr_cert_name = d['opr_cert_name']
        if 'refuse_reason' in d:
            o.refuse_reason = d['refuse_reason']
        if 'sign_order' in d:
            o.sign_order = d['sign_order']
        if 'sign_time' in d:
            o.sign_time = d['sign_time']
        if 'sign_type_code' in d:
            o.sign_type_code = d['sign_type_code']
        if 'syn_time' in d:
            o.syn_time = d['syn_time']
        if 'tx_hash_code' in d:
            o.tx_hash_code = d['tx_hash_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEcoMycarParkingParkinglotinfoQueryModel(object):

    def __init__(self):
        self._out_parking_id = None
        self._parking_id = None

    @property
    def out_parking_id(self):
        return self._out_parking_id

    @out_parking_id.setter
    def out_parking_id(self, value):
        self._out_parking_id = value
    @property
    def parking_id(self):
        return self._parking_id

    @parking_id.setter
    def parking_id(self, value):
        self._parking_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.out_parking_id:
            if hasattr(self.out_parking_id, 'to_alipay_dict'):
                params['out_parking_id'] = self.out_parking_id.to_alipay_dict()
            else:
                params['out_parking_id'] = self.out_parking_id
        if self.parking_id:
            if hasattr(self.parking_id, 'to_alipay_dict'):
                params['parking_id'] = self.parking_id.to_alipay_dict()
            else:
                params['parking_id'] = self.parking_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEcoMycarParkingParkinglotinfoQueryModel()
        if 'out_parking_id' in d:
            o.out_parking_id = d['out_parking_id']
        if 'parking_id' in d:
            o.parking_id = d['parking_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AnttechBlockchainDefinInsuranceReportCreateResponse(AlipayResponse):

    def __init__(self):
        super(AnttechBlockchainDefinInsuranceReportCreateResponse, self).__init__()
        self._parm = None
        self._report_no = None
        self._trade_no = None

    @property
    def parm(self):
        return self._parm

    @parm.setter
    def parm(self, value):
        self._parm = value
    @property
    def report_no(self):
        return self._report_no

    @report_no.setter
    def report_no(self, value):
        self._report_no = value
    @property
    def trade_no(self):
        return self._trade_no

    @trade_no.setter
    def trade_no(self, value):
        self._trade_no = value

    def parse_response_content(self, response_content):
        response = super(AnttechBlockchainDefinInsuranceReportCreateResponse, self).parse_response_content(response_content)
        if 'parm' in response:
            self.parm = response['parm']
        if 'report_no' in response:
            self.report_no = response['report_no']
        if 'trade_no' in response:
            self.trade_no = response['trade_no']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEbppIndustryOnecodepassOrderCreateModel(object):

    def __init__(self):
        self._org_code = None
        self._out_trade_no = None
        self._qr_code = None
        self._seller_id = None
        self._subject = None
        self._timeout_express = None
        self._total_amount = None

    @property
    def org_code(self):
        return self._org_code

    @org_code.setter
    def org_code(self, value):
        self._org_code = value
    @property
    def out_trade_no(self):
        return self._out_trade_no

    @out_trade_no.setter
    def out_trade_no(self, value):
        self._out_trade_no = value
    @property
    def qr_code(self):
        return self._qr_code

    @qr_code.setter
    def qr_code(self, value):
        self._qr_code = value
    @property
    def seller_id(self):
        return self._seller_id

    @seller_id.setter
    def seller_id(self, value):
        self._seller_id = value
    @property
    def subject(self):
        return self._subject

    @subject.setter
    def subject(self, value):
        self._subject = value
    @property
    def timeout_express(self):
        return self._timeout_express

    @timeout_express.setter
    def timeout_express(self, value):
        self._timeout_express = value
    @property
    def total_amount(self):
        return self._total_amount

    @total_amount.setter
    def total_amount(self, value):
        self._total_amount = value


    def to_alipay_dict(self):
        params = dict()
        if self.org_code:
            if hasattr(self.org_code, 'to_alipay_dict'):
                params['org_code'] = self.org_code.to_alipay_dict()
            else:
                params['org_code'] = self.org_code
        if self.out_trade_no:
            if hasattr(self.out_trade_no, 'to_alipay_dict'):
                params['out_trade_no'] = self.out_trade_no.to_alipay_dict()
            else:
                params['out_trade_no'] = self.out_trade_no
        if self.qr_code:
            if hasattr(self.qr_code, 'to_alipay_dict'):
                params['qr_code'] = self.qr_code.to_alipay_dict()
            else:
                params['qr_code'] = self.qr_code
        if self.seller_id:
            if hasattr(self.seller_id, 'to_alipay_dict'):
                params['seller_id'] = self.seller_id.to_alipay_dict()
            else:
                params['seller_id'] = self.seller_id
        if self.subject:
            if hasattr(self.subject, 'to_alipay_dict'):
                params['subject'] = self.subject.to_alipay_dict()
            else:
                params['subject'] = self.subject
        if self.timeout_express:
            if hasattr(self.timeout_express, 'to_alipay_dict'):
                params['timeout_express'] = self.timeout_express.to_alipay_dict()
            else:
                params['timeout_express'] = self.timeout_express
        if self.total_amount:
            if hasattr(self.total_amount, 'to_alipay_dict'):
                params['total_amount'] = self.total_amount.to_alipay_dict()
            else:
                params['total_amount'] = self.total_amount
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEbppIndustryOnecodepassOrderCreateModel()
        if 'org_code' in d:
            o.org_code = d['org_code']
        if 'out_trade_no' in d:
            o.out_trade_no = d['out_trade_no']
        if 'qr_code' in d:
            o.qr_code = d['qr_code']
        if 'seller_id' in d:
            o.seller_id = d['seller_id']
        if 'subject' in d:
            o.subject = d['subject']
        if 'timeout_express' in d:
            o.timeout_express = d['timeout_express']
        if 'total_amount' in d:
            o.total_amount = d['total_amount']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayIserviceCliveSystemSendModel(object):

    def __init__(self):
        self._content = None
        self._conversation_id = None
        self._src = None
        self._visitor_id = None

    @property
    def content(self):
        return self._content

    @content.setter
    def content(self, value):
        self._content = value
    @property
    def conversation_id(self):
        return self._conversation_id

    @conversation_id.setter
    def conversation_id(self, value):
        self._conversation_id = value
    @property
    def src(self):
        return self._src

    @src.setter
    def src(self, value):
        self._src = value
    @property
    def visitor_id(self):
        return self._visitor_id

    @visitor_id.setter
    def visitor_id(self, value):
        self._visitor_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.content:
            if hasattr(self.content, 'to_alipay_dict'):
                params['content'] = self.content.to_alipay_dict()
            else:
                params['content'] = self.content
        if self.conversation_id:
            if hasattr(self.conversation_id, 'to_alipay_dict'):
                params['conversation_id'] = self.conversation_id.to_alipay_dict()
            else:
                params['conversation_id'] = self.conversation_id
        if self.src:
            if hasattr(self.src, 'to_alipay_dict'):
                params['src'] = self.src.to_alipay_dict()
            else:
                params['src'] = self.src
        if self.visitor_id:
            if hasattr(self.visitor_id, 'to_alipay_dict'):
                params['visitor_id'] = self.visitor_id.to_alipay_dict()
            else:
                params['visitor_id'] = self.visitor_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayIserviceCliveSystemSendModel()
        if 'content' in d:
            o.content = d['content']
        if 'conversation_id' in d:
            o.conversation_id = d['conversation_id']
        if 'src' in d:
            o.src = d['src']
        if 'visitor_id' in d:
            o.visitor_id = d['visitor_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayDigitalmgmtLandcoreLandcoretpspJhbpmSyncModel(object):

    def __init__(self):
        self._puid = None

    @property
    def puid(self):
        return self._puid

    @puid.setter
    def puid(self, value):
        self._puid = value


    def to_alipay_dict(self):
        params = dict()
        if self.puid:
            if hasattr(self.puid, 'to_alipay_dict'):
                params['puid'] = self.puid.to_alipay_dict()
            else:
                params['puid'] = self.puid
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayDigitalmgmtLandcoreLandcoretpspJhbpmSyncModel()
        if 'puid' in d:
            o.puid = d['puid']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.AccessParams import AccessParams
from alipay.aop.api.domain.PeriodRuleParams import PeriodRuleParams
from alipay.aop.api.domain.SignMerchantParams import SignMerchantParams


class SignParams(object):

    def __init__(self):
        self._access_params = None
        self._allow_huazhi_degrade = None
        self._external_agreement_no = None
        self._external_logon_id = None
        self._period_rule_params = None
        self._personal_product_code = None
        self._sign_notify_url = None
        self._sign_scene = None
        self._sub_merchant = None

    @property
    def access_params(self):
        return self._access_params

    @access_params.setter
    def access_params(self, value):
        if isinstance(value, AccessParams):
            self._access_params = value
        else:
            self._access_params = AccessParams.from_alipay_dict(value)
    @property
    def allow_huazhi_degrade(self):
        return self._allow_huazhi_degrade

    @allow_huazhi_degrade.setter
    def allow_huazhi_degrade(self, value):
        self._allow_huazhi_degrade = value
    @property
    def external_agreement_no(self):
        return self._external_agreement_no

    @external_agreement_no.setter
    def external_agreement_no(self, value):
        self._external_agreement_no = value
    @property
    def external_logon_id(self):
        return self._external_logon_id

    @external_logon_id.setter
    def external_logon_id(self, value):
        self._external_logon_id = value
    @property
    def period_rule_params(self):
        return self._period_rule_params

    @period_rule_params.setter
    def period_rule_params(self, value):
        if isinstance(value, PeriodRuleParams):
            self._period_rule_params = value
        else:
            self._period_rule_params = PeriodRuleParams.from_alipay_dict(value)
    @property
    def personal_product_code(self):
        return self._personal_product_code

    @personal_product_code.setter
    def personal_product_code(self, value):
        self._personal_product_code = value
    @property
    def sign_notify_url(self):
        return self._sign_notify_url

    @sign_notify_url.setter
    def sign_notify_url(self, value):
        self._sign_notify_url = value
    @property
    def sign_scene(self):
        return self._sign_scene

    @sign_scene.setter
    def sign_scene(self, value):
        self._sign_scene = value
    @property
    def sub_merchant(self):
        return self._sub_merchant

    @sub_merchant.setter
    def sub_merchant(self, value):
        if isinstance(value, SignMerchantParams):
            self._sub_merchant = value
        else:
            self._sub_merchant = SignMerchantParams.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.access_params:
            if hasattr(self.access_params, 'to_alipay_dict'):
                params['access_params'] = self.access_params.to_alipay_dict()
            else:
                params['access_params'] = self.access_params
        if self.allow_huazhi_degrade:
            if hasattr(self.allow_huazhi_degrade, 'to_alipay_dict'):
                params['allow_huazhi_degrade'] = self.allow_huazhi_degrade.to_alipay_dict()
            else:
                params['allow_huazhi_degrade'] = self.allow_huazhi_degrade
        if self.external_agreement_no:
            if hasattr(self.external_agreement_no, 'to_alipay_dict'):
                params['external_agreement_no'] = self.external_agreement_no.to_alipay_dict()
            else:
                params['external_agreement_no'] = self.external_agreement_no
        if self.external_logon_id:
            if hasattr(self.external_logon_id, 'to_alipay_dict'):
                params['external_logon_id'] = self.external_logon_id.to_alipay_dict()
            else:
                params['external_logon_id'] = self.external_logon_id
        if self.period_rule_params:
            if hasattr(self.period_rule_params, 'to_alipay_dict'):
                params['period_rule_params'] = self.period_rule_params.to_alipay_dict()
            else:
                params['period_rule_params'] = self.period_rule_params
        if self.personal_product_code:
            if hasattr(self.personal_product_code, 'to_alipay_dict'):
                params['personal_product_code'] = self.personal_product_code.to_alipay_dict()
            else:
                params['personal_product_code'] = self.personal_product_code
        if self.sign_notify_url:
            if hasattr(self.sign_notify_url, 'to_alipay_dict'):
                params['sign_notify_url'] = self.sign_notify_url.to_alipay_dict()
            else:
                params['sign_notify_url'] = self.sign_notify_url
        if self.sign_scene:
            if hasattr(self.sign_scene, 'to_alipay_dict'):
                params['sign_scene'] = self.sign_scene.to_alipay_dict()
            else:
                params['sign_scene'] = self.sign_scene
        if self.sub_merchant:
            if hasattr(self.sub_merchant, 'to_alipay_dict'):
                params['sub_merchant'] = self.sub_merchant.to_alipay_dict()
            else:
                params['sub_merchant'] = self.sub_merchant
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = SignParams()
        if 'access_params' in d:
            o.access_params = d['access_params']
        if 'allow_huazhi_degrade' in d:
            o.allow_huazhi_degrade = d['allow_huazhi_degrade']
        if 'external_agreement_no' in d:
            o.external_agreement_no = d['external_agreement_no']
        if 'external_logon_id' in d:
            o.external_logon_id = d['external_logon_id']
        if 'period_rule_params' in d:
            o.period_rule_params = d['period_rule_params']
        if 'personal_product_code' in d:
            o.personal_product_code = d['personal_product_code']
        if 'sign_notify_url' in d:
            o.sign_notify_url = d['sign_notify_url']
        if 'sign_scene' in d:
            o.sign_scene = d['sign_scene']
        if 'sub_merchant' in d:
            o.sub_merchant = d['sub_merchant']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ServiceInfoObj(object):

    def __init__(self):
        self._service_category = None
        self._service_content = None
        self._service_type = None

    @property
    def service_category(self):
        return self._service_category

    @service_category.setter
    def service_category(self, value):
        self._service_category = value
    @property
    def service_content(self):
        return self._service_content

    @service_content.setter
    def service_content(self, value):
        self._service_content = value
    @property
    def service_type(self):
        return self._service_type

    @service_type.setter
    def service_type(self, value):
        self._service_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.service_category:
            if hasattr(self.service_category, 'to_alipay_dict'):
                params['service_category'] = self.service_category.to_alipay_dict()
            else:
                params['service_category'] = self.service_category
        if self.service_content:
            if hasattr(self.service_content, 'to_alipay_dict'):
                params['service_content'] = self.service_content.to_alipay_dict()
            else:
                params['service_content'] = self.service_content
        if self.service_type:
            if hasattr(self.service_type, 'to_alipay_dict'):
                params['service_type'] = self.service_type.to_alipay_dict()
            else:
                params['service_type'] = self.service_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ServiceInfoObj()
        if 'service_category' in d:
            o.service_category = d['service_category']
        if 'service_content' in d:
            o.service_content = d['service_content']
        if 'service_type' in d:
            o.service_type = d['service_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.InvoiceTitleModel import InvoiceTitleModel


class AlipayEbppInvoiceTitleListGetResponse(AlipayResponse):

    def __init__(self):
        super(AlipayEbppInvoiceTitleListGetResponse, self).__init__()
        self._title_list = None

    @property
    def title_list(self):
        return self._title_list

    @title_list.setter
    def title_list(self, value):
        if isinstance(value, list):
            self._title_list = list()
            for i in value:
                if isinstance(i, InvoiceTitleModel):
                    self._title_list.append(i)
                else:
                    self._title_list.append(InvoiceTitleModel.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayEbppInvoiceTitleListGetResponse, self).parse_response_content(response_content)
        if 'title_list' in response:
            self.title_list = response['title_list']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class LoginForm(object):

    def __init__(self):
        self._captcha = None
        self._id_card_no = None
        self._name = None
        self._phone_no = None
        self._query_password = None
        self._service_password = None
        self._sms_code = None
        self._sms_code_jldx = None

    @property
    def captcha(self):
        return self._captcha

    @captcha.setter
    def captcha(self, value):
        self._captcha = value
    @property
    def id_card_no(self):
        return self._id_card_no

    @id_card_no.setter
    def id_card_no(self, value):
        self._id_card_no = value
    @property
    def name(self):
        return self._name

    @name.setter
    def name(self, value):
        self._name = value
    @property
    def phone_no(self):
        return self._phone_no

    @phone_no.setter
    def phone_no(self, value):
        self._phone_no = value
    @property
    def query_password(self):
        return self._query_password

    @query_password.setter
    def query_password(self, value):
        self._query_password = value
    @property
    def service_password(self):
        return self._service_password

    @service_password.setter
    def service_password(self, value):
        self._service_password = value
    @property
    def sms_code(self):
        return self._sms_code

    @sms_code.setter
    def sms_code(self, value):
        self._sms_code = value
    @property
    def sms_code_jldx(self):
        return self._sms_code_jldx

    @sms_code_jldx.setter
    def sms_code_jldx(self, value):
        self._sms_code_jldx = value


    def to_alipay_dict(self):
        params = dict()
        if self.captcha:
            if hasattr(self.captcha, 'to_alipay_dict'):
                params['captcha'] = self.captcha.to_alipay_dict()
            else:
                params['captcha'] = self.captcha
        if self.id_card_no:
            if hasattr(self.id_card_no, 'to_alipay_dict'):
                params['id_card_no'] = self.id_card_no.to_alipay_dict()
            else:
                params['id_card_no'] = self.id_card_no
        if self.name:
            if hasattr(self.name, 'to_alipay_dict'):
                params['name'] = self.name.to_alipay_dict()
            else:
                params['name'] = self.name
        if self.phone_no:
            if hasattr(self.phone_no, 'to_alipay_dict'):
                params['phone_no'] = self.phone_no.to_alipay_dict()
            else:
                params['phone_no'] = self.phone_no
        if self.query_password:
            if hasattr(self.query_password, 'to_alipay_dict'):
                params['query_password'] = self.query_password.to_alipay_dict()
            else:
                params['query_password'] = self.query_password
        if self.service_password:
            if hasattr(self.service_password, 'to_alipay_dict'):
                params['service_password'] = self.service_password.to_alipay_dict()
            else:
                params['service_password'] = self.service_password
        if self.sms_code:
            if hasattr(self.sms_code, 'to_alipay_dict'):
                params['sms_code'] = self.sms_code.to_alipay_dict()
            else:
                params['sms_code'] = self.sms_code
        if self.sms_code_jldx:
            if hasattr(self.sms_code_jldx, 'to_alipay_dict'):
                params['sms_code_jldx'] = self.sms_code_jldx.to_alipay_dict()
            else:
                params['sms_code_jldx'] = self.sms_code_jldx
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = LoginForm()
        if 'captcha' in d:
            o.captcha = d['captcha']
        if 'id_card_no' in d:
            o.id_card_no = d['id_card_no']
        if 'name' in d:
            o.name = d['name']
        if 'phone_no' in d:
            o.phone_no = d['phone_no']
        if 'query_password' in d:
            o.query_password = d['query_password']
        if 'service_password' in d:
            o.service_password = d['service_password']
        if 'sms_code' in d:
            o.sms_code = d['sms_code']
        if 'sms_code_jldx' in d:
            o.sms_code_jldx = d['sms_code_jldx']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class VoucherMiniAppUseGuideInfo(object):

    def __init__(self):
        self._mini_app_service_codes = None
        self._mini_app_url = None

    @property
    def mini_app_service_codes(self):
        return self._mini_app_service_codes

    @mini_app_service_codes.setter
    def mini_app_service_codes(self, value):
        if isinstance(value, list):
            self._mini_app_service_codes = list()
            for i in value:
                self._mini_app_service_codes.append(i)
    @property
    def mini_app_url(self):
        return self._mini_app_url

    @mini_app_url.setter
    def mini_app_url(self, value):
        self._mini_app_url = value


    def to_alipay_dict(self):
        params = dict()
        if self.mini_app_service_codes:
            if isinstance(self.mini_app_service_codes, list):
                for i in range(0, len(self.mini_app_service_codes)):
                    element = self.mini_app_service_codes[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.mini_app_service_codes[i] = element.to_alipay_dict()
            if hasattr(self.mini_app_service_codes, 'to_alipay_dict'):
                params['mini_app_service_codes'] = self.mini_app_service_codes.to_alipay_dict()
            else:
                params['mini_app_service_codes'] = self.mini_app_service_codes
        if self.mini_app_url:
            if hasattr(self.mini_app_url, 'to_alipay_dict'):
                params['mini_app_url'] = self.mini_app_url.to_alipay_dict()
            else:
                params['mini_app_url'] = self.mini_app_url
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = VoucherMiniAppUseGuideInfo()
        if 'mini_app_service_codes' in d:
            o.mini_app_service_codes = d['mini_app_service_codes']
        if 'mini_app_url' in d:
            o.mini_app_url = d['mini_app_url']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.ExtCardInfo import ExtCardInfo


class AlipayFundTransTrusteeshipAccountCreateResponse(AlipayResponse):

    def __init__(self):
        super(AlipayFundTransTrusteeshipAccountCreateResponse, self).__init__()
        self._alipay_account_no = None
        self._alipay_open_id = None
        self._alipay_user_id = None
        self._ext_card_info = None

    @property
    def alipay_account_no(self):
        return self._alipay_account_no

    @alipay_account_no.setter
    def alipay_account_no(self, value):
        self._alipay_account_no = value
    @property
    def alipay_open_id(self):
        return self._alipay_open_id

    @alipay_open_id.setter
    def alipay_open_id(self, value):
        self._alipay_open_id = value
    @property
    def alipay_user_id(self):
        return self._alipay_user_id

    @alipay_user_id.setter
    def alipay_user_id(self, value):
        self._alipay_user_id = value
    @property
    def ext_card_info(self):
        return self._ext_card_info

    @ext_card_info.setter
    def ext_card_info(self, value):
        if isinstance(value, ExtCardInfo):
            self._ext_card_info = value
        else:
            self._ext_card_info = ExtCardInfo.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(AlipayFundTransTrusteeshipAccountCreateResponse, self).parse_response_content(response_content)
        if 'alipay_account_no' in response:
            self.alipay_account_no = response['alipay_account_no']
        if 'alipay_open_id' in response:
            self.alipay_open_id = response['alipay_open_id']
        if 'alipay_user_id' in response:
            self.alipay_user_id = response['alipay_user_id']
        if 'ext_card_info' in response:
            self.ext_card_info = response['ext_card_info']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AnttechBlockchainFinanceAssetIssueSubmitModel(object):

    def __init__(self):
        self._asset_id = None
        self._pub_key = None
        self._sign_algorithm = None
        self._sign_data = None
        self._signature = None

    @property
    def asset_id(self):
        return self._asset_id

    @asset_id.setter
    def asset_id(self, value):
        self._asset_id = value
    @property
    def pub_key(self):
        return self._pub_key

    @pub_key.setter
    def pub_key(self, value):
        self._pub_key = value
    @property
    def sign_algorithm(self):
        return self._sign_algorithm

    @sign_algorithm.setter
    def sign_algorithm(self, value):
        self._sign_algorithm = value
    @property
    def sign_data(self):
        return self._sign_data

    @sign_data.setter
    def sign_data(self, value):
        self._sign_data = value
    @property
    def signature(self):
        return self._signature

    @signature.setter
    def signature(self, value):
        self._signature = value


    def to_alipay_dict(self):
        params = dict()
        if self.asset_id:
            if hasattr(self.asset_id, 'to_alipay_dict'):
                params['asset_id'] = self.asset_id.to_alipay_dict()
            else:
                params['asset_id'] = self.asset_id
        if self.pub_key:
            if hasattr(self.pub_key, 'to_alipay_dict'):
                params['pub_key'] = self.pub_key.to_alipay_dict()
            else:
                params['pub_key'] = self.pub_key
        if self.sign_algorithm:
            if hasattr(self.sign_algorithm, 'to_alipay_dict'):
                params['sign_algorithm'] = self.sign_algorithm.to_alipay_dict()
            else:
                params['sign_algorithm'] = self.sign_algorithm
        if self.sign_data:
            if hasattr(self.sign_data, 'to_alipay_dict'):
                params['sign_data'] = self.sign_data.to_alipay_dict()
            else:
                params['sign_data'] = self.sign_data
        if self.signature:
            if hasattr(self.signature, 'to_alipay_dict'):
                params['signature'] = self.signature.to_alipay_dict()
            else:
                params['signature'] = self.signature
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AnttechBlockchainFinanceAssetIssueSubmitModel()
        if 'asset_id' in d:
            o.asset_id = d['asset_id']
        if 'pub_key' in d:
            o.pub_key = d['pub_key']
        if 'sign_algorithm' in d:
            o.sign_algorithm = d['sign_algorithm']
        if 'sign_data' in d:
            o.sign_data = d['sign_data']
        if 'signature' in d:
            o.signature = d['signature']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class KbAdvertContentPasswordModify(object):

    def __init__(self):
        self._background_img_id = None
        self._brand_name = None
        self._password = None
        self._voucher_logo_id = None

    @property
    def background_img_id(self):
        return self._background_img_id

    @background_img_id.setter
    def background_img_id(self, value):
        self._background_img_id = value
    @property
    def brand_name(self):
        return self._brand_name

    @brand_name.setter
    def brand_name(self, value):
        self._brand_name = value
    @property
    def password(self):
        return self._password

    @password.setter
    def password(self, value):
        self._password = value
    @property
    def voucher_logo_id(self):
        return self._voucher_logo_id

    @voucher_logo_id.setter
    def voucher_logo_id(self, value):
        self._voucher_logo_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.background_img_id:
            if hasattr(self.background_img_id, 'to_alipay_dict'):
                params['background_img_id'] = self.background_img_id.to_alipay_dict()
            else:
                params['background_img_id'] = self.background_img_id
        if self.brand_name:
            if hasattr(self.brand_name, 'to_alipay_dict'):
                params['brand_name'] = self.brand_name.to_alipay_dict()
            else:
                params['brand_name'] = self.brand_name
        if self.password:
            if hasattr(self.password, 'to_alipay_dict'):
                params['password'] = self.password.to_alipay_dict()
            else:
                params['password'] = self.password
        if self.voucher_logo_id:
            if hasattr(self.voucher_logo_id, 'to_alipay_dict'):
                params['voucher_logo_id'] = self.voucher_logo_id.to_alipay_dict()
            else:
                params['voucher_logo_id'] = self.voucher_logo_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KbAdvertContentPasswordModify()
        if 'background_img_id' in d:
            o.background_img_id = d['background_img_id']
        if 'brand_name' in d:
            o.brand_name = d['brand_name']
        if 'password' in d:
            o.password = d['password']
        if 'voucher_logo_id' in d:
            o.voucher_logo_id = d['voucher_logo_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class CategoryRequireInfo(object):

    def __init__(self):
        self._business_licence_required = None
        self._category_code = None
        self._category_name = None
        self._category_requirements = None
        self._door_photo_required = None
        self._special_licence_required = None

    @property
    def business_licence_required(self):
        return self._business_licence_required

    @business_licence_required.setter
    def business_licence_required(self, value):
        self._business_licence_required = value
    @property
    def category_code(self):
        return self._category_code

    @category_code.setter
    def category_code(self, value):
        self._category_code = value
    @property
    def category_name(self):
        return self._category_name

    @category_name.setter
    def category_name(self, value):
        self._category_name = value
    @property
    def category_requirements(self):
        return self._category_requirements

    @category_requirements.setter
    def category_requirements(self, value):
        self._category_requirements = value
    @property
    def door_photo_required(self):
        return self._door_photo_required

    @door_photo_required.setter
    def door_photo_required(self, value):
        self._door_photo_required = value
    @property
    def special_licence_required(self):
        return self._special_licence_required

    @special_licence_required.setter
    def special_licence_required(self, value):
        self._special_licence_required = value


    def to_alipay_dict(self):
        params = dict()
        if self.business_licence_required:
            if hasattr(self.business_licence_required, 'to_alipay_dict'):
                params['business_licence_required'] = self.business_licence_required.to_alipay_dict()
            else:
                params['business_licence_required'] = self.business_licence_required
        if self.category_code:
            if hasattr(self.category_code, 'to_alipay_dict'):
                params['category_code'] = self.category_code.to_alipay_dict()
            else:
                params['category_code'] = self.category_code
        if self.category_name:
            if hasattr(self.category_name, 'to_alipay_dict'):
                params['category_name'] = self.category_name.to_alipay_dict()
            else:
                params['category_name'] = self.category_name
        if self.category_requirements:
            if hasattr(self.category_requirements, 'to_alipay_dict'):
                params['category_requirements'] = self.category_requirements.to_alipay_dict()
            else:
                params['category_requirements'] = self.category_requirements
        if self.door_photo_required:
            if hasattr(self.door_photo_required, 'to_alipay_dict'):
                params['door_photo_required'] = self.door_photo_required.to_alipay_dict()
            else:
                params['door_photo_required'] = self.door_photo_required
        if self.special_licence_required:
            if hasattr(self.special_licence_required, 'to_alipay_dict'):
                params['special_licence_required'] = self.special_licence_required.to_alipay_dict()
            else:
                params['special_licence_required'] = self.special_licence_required
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = CategoryRequireInfo()
        if 'business_licence_required' in d:
            o.business_licence_required = d['business_licence_required']
        if 'category_code' in d:
            o.category_code = d['category_code']
        if 'category_name' in d:
            o.category_name = d['category_name']
        if 'category_requirements' in d:
            o.category_requirements = d['category_requirements']
        if 'door_photo_required' in d:
            o.door_photo_required = d['door_photo_required']
        if 'special_licence_required' in d:
            o.special_licence_required = d['special_licence_required']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEbppJfexportBillQueryModel(object):

    def __init__(self):
        self._bill_no = None
        self._biz_type = None
        self._extend_field = None

    @property
    def bill_no(self):
        return self._bill_no

    @bill_no.setter
    def bill_no(self, value):
        self._bill_no = value
    @property
    def biz_type(self):
        return self._biz_type

    @biz_type.setter
    def biz_type(self, value):
        self._biz_type = value
    @property
    def extend_field(self):
        return self._extend_field

    @extend_field.setter
    def extend_field(self, value):
        self._extend_field = value


    def to_alipay_dict(self):
        params = dict()
        if self.bill_no:
            if hasattr(self.bill_no, 'to_alipay_dict'):
                params['bill_no'] = self.bill_no.to_alipay_dict()
            else:
                params['bill_no'] = self.bill_no
        if self.biz_type:
            if hasattr(self.biz_type, 'to_alipay_dict'):
                params['biz_type'] = self.biz_type.to_alipay_dict()
            else:
                params['biz_type'] = self.biz_type
        if self.extend_field:
            if hasattr(self.extend_field, 'to_alipay_dict'):
                params['extend_field'] = self.extend_field.to_alipay_dict()
            else:
                params['extend_field'] = self.extend_field
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEbppJfexportBillQueryModel()
        if 'bill_no' in d:
            o.bill_no = d['bill_no']
        if 'biz_type' in d:
            o.biz_type = d['biz_type']
        if 'extend_field' in d:
            o.extend_field = d['extend_field']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.DeliveryMerchantInfo import DeliveryMerchantInfo


class DeliveryMerchantRule(object):

    def __init__(self):
        self._brand_id_list = None
        self._delivery_merchant_infos = None
        self._delivery_merchant_mode = None

    @property
    def brand_id_list(self):
        return self._brand_id_list

    @brand_id_list.setter
    def brand_id_list(self, value):
        if isinstance(value, list):
            self._brand_id_list = list()
            for i in value:
                self._brand_id_list.append(i)
    @property
    def delivery_merchant_infos(self):
        return self._delivery_merchant_infos

    @delivery_merchant_infos.setter
    def delivery_merchant_infos(self, value):
        if isinstance(value, list):
            self._delivery_merchant_infos = list()
            for i in value:
                if isinstance(i, DeliveryMerchantInfo):
                    self._delivery_merchant_infos.append(i)
                else:
                    self._delivery_merchant_infos.append(DeliveryMerchantInfo.from_alipay_dict(i))
    @property
    def delivery_merchant_mode(self):
        return self._delivery_merchant_mode

    @delivery_merchant_mode.setter
    def delivery_merchant_mode(self, value):
        self._delivery_merchant_mode = value


    def to_alipay_dict(self):
        params = dict()
        if self.brand_id_list:
            if isinstance(self.brand_id_list, list):
                for i in range(0, len(self.brand_id_list)):
                    element = self.brand_id_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.brand_id_list[i] = element.to_alipay_dict()
            if hasattr(self.brand_id_list, 'to_alipay_dict'):
                params['brand_id_list'] = self.brand_id_list.to_alipay_dict()
            else:
                params['brand_id_list'] = self.brand_id_list
        if self.delivery_merchant_infos:
            if isinstance(self.delivery_merchant_infos, list):
                for i in range(0, len(self.delivery_merchant_infos)):
                    element = self.delivery_merchant_infos[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.delivery_merchant_infos[i] = element.to_alipay_dict()
            if hasattr(self.delivery_merchant_infos, 'to_alipay_dict'):
                params['delivery_merchant_infos'] = self.delivery_merchant_infos.to_alipay_dict()
            else:
                params['delivery_merchant_infos'] = self.delivery_merchant_infos
        if self.delivery_merchant_mode:
            if hasattr(self.delivery_merchant_mode, 'to_alipay_dict'):
                params['delivery_merchant_mode'] = self.delivery_merchant_mode.to_alipay_dict()
            else:
                params['delivery_merchant_mode'] = self.delivery_merchant_mode
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = DeliveryMerchantRule()
        if 'brand_id_list' in d:
            o.brand_id_list = d['brand_id_list']
        if 'delivery_merchant_infos' in d:
            o.delivery_merchant_infos = d['delivery_merchant_infos']
        if 'delivery_merchant_mode' in d:
            o.delivery_merchant_mode = d['delivery_merchant_mode']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class ZhimaCreditPayafteruseCreditagreementSignModel(object):

    def __init__(self):
        self._cancel_back_link = None
        self._category_id = None
        self._external_logon_id = None
        self._extra_param = None
        self._out_agreement_no = None
        self._product_code = None
        self._return_back_link = None
        self._zm_service_id = None

    @property
    def cancel_back_link(self):
        return self._cancel_back_link

    @cancel_back_link.setter
    def cancel_back_link(self, value):
        self._cancel_back_link = value
    @property
    def category_id(self):
        return self._category_id

    @category_id.setter
    def category_id(self, value):
        self._category_id = value
    @property
    def external_logon_id(self):
        return self._external_logon_id

    @external_logon_id.setter
    def external_logon_id(self, value):
        self._external_logon_id = value
    @property
    def extra_param(self):
        return self._extra_param

    @extra_param.setter
    def extra_param(self, value):
        self._extra_param = value
    @property
    def out_agreement_no(self):
        return self._out_agreement_no

    @out_agreement_no.setter
    def out_agreement_no(self, value):
        self._out_agreement_no = value
    @property
    def product_code(self):
        return self._product_code

    @product_code.setter
    def product_code(self, value):
        self._product_code = value
    @property
    def return_back_link(self):
        return self._return_back_link

    @return_back_link.setter
    def return_back_link(self, value):
        self._return_back_link = value
    @property
    def zm_service_id(self):
        return self._zm_service_id

    @zm_service_id.setter
    def zm_service_id(self, value):
        self._zm_service_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.cancel_back_link:
            if hasattr(self.cancel_back_link, 'to_alipay_dict'):
                params['cancel_back_link'] = self.cancel_back_link.to_alipay_dict()
            else:
                params['cancel_back_link'] = self.cancel_back_link
        if self.category_id:
            if hasattr(self.category_id, 'to_alipay_dict'):
                params['category_id'] = self.category_id.to_alipay_dict()
            else:
                params['category_id'] = self.category_id
        if self.external_logon_id:
            if hasattr(self.external_logon_id, 'to_alipay_dict'):
                params['external_logon_id'] = self.external_logon_id.to_alipay_dict()
            else:
                params['external_logon_id'] = self.external_logon_id
        if self.extra_param:
            if hasattr(self.extra_param, 'to_alipay_dict'):
                params['extra_param'] = self.extra_param.to_alipay_dict()
            else:
                params['extra_param'] = self.extra_param
        if self.out_agreement_no:
            if hasattr(self.out_agreement_no, 'to_alipay_dict'):
                params['out_agreement_no'] = self.out_agreement_no.to_alipay_dict()
            else:
                params['out_agreement_no'] = self.out_agreement_no
        if self.product_code:
            if hasattr(self.product_code, 'to_alipay_dict'):
                params['product_code'] = self.product_code.to_alipay_dict()
            else:
                params['product_code'] = self.product_code
        if self.return_back_link:
            if hasattr(self.return_back_link, 'to_alipay_dict'):
                params['return_back_link'] = self.return_back_link.to_alipay_dict()
            else:
                params['return_back_link'] = self.return_back_link
        if self.zm_service_id:
            if hasattr(self.zm_service_id, 'to_alipay_dict'):
                params['zm_service_id'] = self.zm_service_id.to_alipay_dict()
            else:
                params['zm_service_id'] = self.zm_service_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ZhimaCreditPayafteruseCreditagreementSignModel()
        if 'cancel_back_link' in d:
            o.cancel_back_link = d['cancel_back_link']
        if 'category_id' in d:
            o.category_id = d['category_id']
        if 'external_logon_id' in d:
            o.external_logon_id = d['external_logon_id']
        if 'extra_param' in d:
            o.extra_param = d['extra_param']
        if 'out_agreement_no' in d:
            o.out_agreement_no = d['out_agreement_no']
        if 'product_code' in d:
            o.product_code = d['product_code']
        if 'return_back_link' in d:
            o.return_back_link = d['return_back_link']
        if 'zm_service_id' in d:
            o.zm_service_id = d['zm_service_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.LinkTypeListResult import LinkTypeListResult


class AlipayDigitalmgmtLinktypeQueryResponse(AlipayResponse):

    def __init__(self):
        super(AlipayDigitalmgmtLinktypeQueryResponse, self).__init__()
        self._link_type_list_result = None

    @property
    def link_type_list_result(self):
        return self._link_type_list_result

    @link_type_list_result.setter
    def link_type_list_result(self, value):
        if isinstance(value, LinkTypeListResult):
            self._link_type_list_result = value
        else:
            self._link_type_list_result = LinkTypeListResult.from_alipay_dict(value)

    def parse_response_content(self, response_content):
        response = super(AlipayDigitalmgmtLinktypeQueryResponse, self).parse_response_content(response_content)
        if 'link_type_list_result' in response:
            self.link_type_list_result = response['link_type_list_result']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class CarRentalInfo(object):

    def __init__(self):
        self._billing_start_time = None
        self._driving_duration = None
        self._driving_mileage = None
        self._duration_unit_price = None
        self._estimate_lease_end_time = None
        self._estimate_lease_start_time = None
        self._free_cancellation_time = None
        self._mileage_unit_price = None
        self._package_duration = None
        self._package_mileage = None
        self._package_name = None
        self._real_lease_end_time = None
        self._real_lease_start_time = None
        self._shopid_car_return = None
        self._shopid_car_taken = None
        self._upper_limit_amount = None

    @property
    def billing_start_time(self):
        return self._billing_start_time

    @billing_start_time.setter
    def billing_start_time(self, value):
        self._billing_start_time = value
    @property
    def driving_duration(self):
        return self._driving_duration

    @driving_duration.setter
    def driving_duration(self, value):
        self._driving_duration = value
    @property
    def driving_mileage(self):
        return self._driving_mileage

    @driving_mileage.setter
    def driving_mileage(self, value):
        self._driving_mileage = value
    @property
    def duration_unit_price(self):
        return self._duration_unit_price

    @duration_unit_price.setter
    def duration_unit_price(self, value):
        self._duration_unit_price = value
    @property
    def estimate_lease_end_time(self):
        return self._estimate_lease_end_time

    @estimate_lease_end_time.setter
    def estimate_lease_end_time(self, value):
        self._estimate_lease_end_time = value
    @property
    def estimate_lease_start_time(self):
        return self._estimate_lease_start_time

    @estimate_lease_start_time.setter
    def estimate_lease_start_time(self, value):
        self._estimate_lease_start_time = value
    @property
    def free_cancellation_time(self):
        return self._free_cancellation_time

    @free_cancellation_time.setter
    def free_cancellation_time(self, value):
        self._free_cancellation_time = value
    @property
    def mileage_unit_price(self):
        return self._mileage_unit_price

    @mileage_unit_price.setter
    def mileage_unit_price(self, value):
        self._mileage_unit_price = value
    @property
    def package_duration(self):
        return self._package_duration

    @package_duration.setter
    def package_duration(self, value):
        self._package_duration = value
    @property
    def package_mileage(self):
        return self._package_mileage

    @package_mileage.setter
    def package_mileage(self, value):
        self._package_mileage = value
    @property
    def package_name(self):
        return self._package_name

    @package_name.setter
    def package_name(self, value):
        self._package_name = value
    @property
    def real_lease_end_time(self):
        return self._real_lease_end_time

    @real_lease_end_time.setter
    def real_lease_end_time(self, value):
        self._real_lease_end_time = value
    @property
    def real_lease_start_time(self):
        return self._real_lease_start_time

    @real_lease_start_time.setter
    def real_lease_start_time(self, value):
        self._real_lease_start_time = value
    @property
    def shopid_car_return(self):
        return self._shopid_car_return

    @shopid_car_return.setter
    def shopid_car_return(self, value):
        self._shopid_car_return = value
    @property
    def shopid_car_taken(self):
        return self._shopid_car_taken

    @shopid_car_taken.setter
    def shopid_car_taken(self, value):
        self._shopid_car_taken = value
    @property
    def upper_limit_amount(self):
        return self._upper_limit_amount

    @upper_limit_amount.setter
    def upper_limit_amount(self, value):
        self._upper_limit_amount = value


    def to_alipay_dict(self):
        params = dict()
        if self.billing_start_time:
            if hasattr(self.billing_start_time, 'to_alipay_dict'):
                params['billing_start_time'] = self.billing_start_time.to_alipay_dict()
            else:
                params['billing_start_time'] = self.billing_start_time
        if self.driving_duration:
            if hasattr(self.driving_duration, 'to_alipay_dict'):
                params['driving_duration'] = self.driving_duration.to_alipay_dict()
            else:
                params['driving_duration'] = self.driving_duration
        if self.driving_mileage:
            if hasattr(self.driving_mileage, 'to_alipay_dict'):
                params['driving_mileage'] = self.driving_mileage.to_alipay_dict()
            else:
                params['driving_mileage'] = self.driving_mileage
        if self.duration_unit_price:
            if hasattr(self.duration_unit_price, 'to_alipay_dict'):
                params['duration_unit_price'] = self.duration_unit_price.to_alipay_dict()
            else:
                params['duration_unit_price'] = self.duration_unit_price
        if self.estimate_lease_end_time:
            if hasattr(self.estimate_lease_end_time, 'to_alipay_dict'):
                params['estimate_lease_end_time'] = self.estimate_lease_end_time.to_alipay_dict()
            else:
                params['estimate_lease_end_time'] = self.estimate_lease_end_time
        if self.estimate_lease_start_time:
            if hasattr(self.estimate_lease_start_time, 'to_alipay_dict'):
                params['estimate_lease_start_time'] = self.estimate_lease_start_time.to_alipay_dict()
            else:
                params['estimate_lease_start_time'] = self.estimate_lease_start_time
        if self.free_cancellation_time:
            if hasattr(self.free_cancellation_time, 'to_alipay_dict'):
                params['free_cancellation_time'] = self.free_cancellation_time.to_alipay_dict()
            else:
                params['free_cancellation_time'] = self.free_cancellation_time
        if self.mileage_unit_price:
            if hasattr(self.mileage_unit_price, 'to_alipay_dict'):
                params['mileage_unit_price'] = self.mileage_unit_price.to_alipay_dict()
            else:
                params['mileage_unit_price'] = self.mileage_unit_price
        if self.package_duration:
            if hasattr(self.package_duration, 'to_alipay_dict'):
                params['package_duration'] = self.package_duration.to_alipay_dict()
            else:
                params['package_duration'] = self.package_duration
        if self.package_mileage:
            if hasattr(self.package_mileage, 'to_alipay_dict'):
                params['package_mileage'] = self.package_mileage.to_alipay_dict()
            else:
                params['package_mileage'] = self.package_mileage
        if self.package_name:
            if hasattr(self.package_name, 'to_alipay_dict'):
                params['package_name'] = self.package_name.to_alipay_dict()
            else:
                params['package_name'] = self.package_name
        if self.real_lease_end_time:
            if hasattr(self.real_lease_end_time, 'to_alipay_dict'):
                params['real_lease_end_time'] = self.real_lease_end_time.to_alipay_dict()
            else:
                params['real_lease_end_time'] = self.real_lease_end_time
        if self.real_lease_start_time:
            if hasattr(self.real_lease_start_time, 'to_alipay_dict'):
                params['real_lease_start_time'] = self.real_lease_start_time.to_alipay_dict()
            else:
                params['real_lease_start_time'] = self.real_lease_start_time
        if self.shopid_car_return:
            if hasattr(self.shopid_car_return, 'to_alipay_dict'):
                params['shopid_car_return'] = self.shopid_car_return.to_alipay_dict()
            else:
                params['shopid_car_return'] = self.shopid_car_return
        if self.shopid_car_taken:
            if hasattr(self.shopid_car_taken, 'to_alipay_dict'):
                params['shopid_car_taken'] = self.shopid_car_taken.to_alipay_dict()
            else:
                params['shopid_car_taken'] = self.shopid_car_taken
        if self.upper_limit_amount:
            if hasattr(self.upper_limit_amount, 'to_alipay_dict'):
                params['upper_limit_amount'] = self.upper_limit_amount.to_alipay_dict()
            else:
                params['upper_limit_amount'] = self.upper_limit_amount
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = CarRentalInfo()
        if 'billing_start_time' in d:
            o.billing_start_time = d['billing_start_time']
        if 'driving_duration' in d:
            o.driving_duration = d['driving_duration']
        if 'driving_mileage' in d:
            o.driving_mileage = d['driving_mileage']
        if 'duration_unit_price' in d:
            o.duration_unit_price = d['duration_unit_price']
        if 'estimate_lease_end_time' in d:
            o.estimate_lease_end_time = d['estimate_lease_end_time']
        if 'estimate_lease_start_time' in d:
            o.estimate_lease_start_time = d['estimate_lease_start_time']
        if 'free_cancellation_time' in d:
            o.free_cancellation_time = d['free_cancellation_time']
        if 'mileage_unit_price' in d:
            o.mileage_unit_price = d['mileage_unit_price']
        if 'package_duration' in d:
            o.package_duration = d['package_duration']
        if 'package_mileage' in d:
            o.package_mileage = d['package_mileage']
        if 'package_name' in d:
            o.package_name = d['package_name']
        if 'real_lease_end_time' in d:
            o.real_lease_end_time = d['real_lease_end_time']
        if 'real_lease_start_time' in d:
            o.real_lease_start_time = d['real_lease_start_time']
        if 'shopid_car_return' in d:
            o.shopid_car_return = d['shopid_car_return']
        if 'shopid_car_taken' in d:
            o.shopid_car_taken = d['shopid_car_taken']
        if 'upper_limit_amount' in d:
            o.upper_limit_amount = d['upper_limit_amount']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.OpenAPIContractRiskResult import OpenAPIContractRiskResult


class AlipayBossProdContractRiskCreateResponse(AlipayResponse):

    def __init__(self):
        super(AlipayBossProdContractRiskCreateResponse, self).__init__()
        self._business_id = None
        self._open_api_contract_risk_result_list = None
        self._result_code = None
        self._result_message = None
        self._result_success = None
        self._result_trace_id = None

    @property
    def business_id(self):
        return self._business_id

    @business_id.setter
    def business_id(self, value):
        self._business_id = value
    @property
    def open_api_contract_risk_result_list(self):
        return self._open_api_contract_risk_result_list

    @open_api_contract_risk_result_list.setter
    def open_api_contract_risk_result_list(self, value):
        if isinstance(value, list):
            self._open_api_contract_risk_result_list = list()
            for i in value:
                if isinstance(i, OpenAPIContractRiskResult):
                    self._open_api_contract_risk_result_list.append(i)
                else:
                    self._open_api_contract_risk_result_list.append(OpenAPIContractRiskResult.from_alipay_dict(i))
    @property
    def result_code(self):
        return self._result_code

    @result_code.setter
    def result_code(self, value):
        self._result_code = value
    @property
    def result_message(self):
        return self._result_message

    @result_message.setter
    def result_message(self, value):
        self._result_message = value
    @property
    def result_success(self):
        return self._result_success

    @result_success.setter
    def result_success(self, value):
        self._result_success = value
    @property
    def result_trace_id(self):
        return self._result_trace_id

    @result_trace_id.setter
    def result_trace_id(self, value):
        self._result_trace_id = value

    def parse_response_content(self, response_content):
        response = super(AlipayBossProdContractRiskCreateResponse, self).parse_response_content(response_content)
        if 'business_id' in response:
            self.business_id = response['business_id']
        if 'open_api_contract_risk_result_list' in response:
            self.open_api_contract_risk_result_list = response['open_api_contract_risk_result_list']
        if 'result_code' in response:
            self.result_code = response['result_code']
        if 'result_message' in response:
            self.result_message = response['result_message']
        if 'result_success' in response:
            self.result_success = response['result_success']
        if 'result_trace_id' in response:
            self.result_trace_id = response['result_trace_id']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class KoubeiMarketingAdvertisingOperateModel(object):

    def __init__(self):
        self._ad_id = None
        self._operate_type = None

    @property
    def ad_id(self):
        return self._ad_id

    @ad_id.setter
    def ad_id(self, value):
        self._ad_id = value
    @property
    def operate_type(self):
        return self._operate_type

    @operate_type.setter
    def operate_type(self, value):
        self._operate_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.ad_id:
            if hasattr(self.ad_id, 'to_alipay_dict'):
                params['ad_id'] = self.ad_id.to_alipay_dict()
            else:
                params['ad_id'] = self.ad_id
        if self.operate_type:
            if hasattr(self.operate_type, 'to_alipay_dict'):
                params['operate_type'] = self.operate_type.to_alipay_dict()
            else:
                params['operate_type'] = self.operate_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = KoubeiMarketingAdvertisingOperateModel()
        if 'ad_id' in d:
            o.ad_id = d['ad_id']
        if 'operate_type' in d:
            o.operate_type = d['operate_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.MorphoMiniMeta import MorphoMiniMeta
from alipay.aop.api.domain.MorphoUser import MorphoUser


class MorphoAppItem(object):

    def __init__(self):
        self._gmt_modified = None
        self._id = None
        self._mini_meta = None
        self._online_state = None
        self._owner = None
        self._status = None
        self._title = None
        self._type = None

    @property
    def gmt_modified(self):
        return self._gmt_modified

    @gmt_modified.setter
    def gmt_modified(self, value):
        self._gmt_modified = value
    @property
    def id(self):
        return self._id

    @id.setter
    def id(self, value):
        self._id = value
    @property
    def mini_meta(self):
        return self._mini_meta

    @mini_meta.setter
    def mini_meta(self, value):
        if isinstance(value, MorphoMiniMeta):
            self._mini_meta = value
        else:
            self._mini_meta = MorphoMiniMeta.from_alipay_dict(value)
    @property
    def online_state(self):
        return self._online_state

    @online_state.setter
    def online_state(self, value):
        self._online_state = value
    @property
    def owner(self):
        return self._owner

    @owner.setter
    def owner(self, value):
        if isinstance(value, MorphoUser):
            self._owner = value
        else:
            self._owner = MorphoUser.from_alipay_dict(value)
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def title(self):
        return self._title

    @title.setter
    def title(self, value):
        self._title = value
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value


    def to_alipay_dict(self):
        params = dict()
        if self.gmt_modified:
            if hasattr(self.gmt_modified, 'to_alipay_dict'):
                params['gmt_modified'] = self.gmt_modified.to_alipay_dict()
            else:
                params['gmt_modified'] = self.gmt_modified
        if self.id:
            if hasattr(self.id, 'to_alipay_dict'):
                params['id'] = self.id.to_alipay_dict()
            else:
                params['id'] = self.id
        if self.mini_meta:
            if hasattr(self.mini_meta, 'to_alipay_dict'):
                params['mini_meta'] = self.mini_meta.to_alipay_dict()
            else:
                params['mini_meta'] = self.mini_meta
        if self.online_state:
            if hasattr(self.online_state, 'to_alipay_dict'):
                params['online_state'] = self.online_state.to_alipay_dict()
            else:
                params['online_state'] = self.online_state
        if self.owner:
            if hasattr(self.owner, 'to_alipay_dict'):
                params['owner'] = self.owner.to_alipay_dict()
            else:
                params['owner'] = self.owner
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.title:
            if hasattr(self.title, 'to_alipay_dict'):
                params['title'] = self.title.to_alipay_dict()
            else:
                params['title'] = self.title
        if self.type:
            if hasattr(self.type, 'to_alipay_dict'):
                params['type'] = self.type.to_alipay_dict()
            else:
                params['type'] = self.type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MorphoAppItem()
        if 'gmt_modified' in d:
            o.gmt_modified = d['gmt_modified']
        if 'id' in d:
            o.id = d['id']
        if 'mini_meta' in d:
            o.mini_meta = d['mini_meta']
        if 'online_state' in d:
            o.online_state = d['online_state']
        if 'owner' in d:
            o.owner = d['owner']
        if 'status' in d:
            o.status = d['status']
        if 'title' in d:
            o.title = d['title']
        if 'type' in d:
            o.type = d['type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayCommerceTransportEtcSettlementApplyModel(object):

    def __init__(self):
        self._biz_agreement_no = None
        self._car_type = None
        self._end_station_name = None
        self._end_time = None
        self._memo = None
        self._out_order_id = None
        self._plate_color = None
        self._plate_no = None
        self._seller_id = None
        self._start_station_name = None
        self._start_time = None
        self._sub_scene = None
        self._sub_type = None
        self._subject = None
        self._total_amount = None

    @property
    def biz_agreement_no(self):
        return self._biz_agreement_no

    @biz_agreement_no.setter
    def biz_agreement_no(self, value):
        self._biz_agreement_no = value
    @property
    def car_type(self):
        return self._car_type

    @car_type.setter
    def car_type(self, value):
        self._car_type = value
    @property
    def end_station_name(self):
        return self._end_station_name

    @end_station_name.setter
    def end_station_name(self, value):
        self._end_station_name = value
    @property
    def end_time(self):
        return self._end_time

    @end_time.setter
    def end_time(self, value):
        self._end_time = value
    @property
    def memo(self):
        return self._memo

    @memo.setter
    def memo(self, value):
        self._memo = value
    @property
    def out_order_id(self):
        return self._out_order_id

    @out_order_id.setter
    def out_order_id(self, value):
        self._out_order_id = value
    @property
    def plate_color(self):
        return self._plate_color

    @plate_color.setter
    def plate_color(self, value):
        self._plate_color = value
    @property
    def plate_no(self):
        return self._plate_no

    @plate_no.setter
    def plate_no(self, value):
        self._plate_no = value
    @property
    def seller_id(self):
        return self._seller_id

    @seller_id.setter
    def seller_id(self, value):
        self._seller_id = value
    @property
    def start_station_name(self):
        return self._start_station_name

    @start_station_name.setter
    def start_station_name(self, value):
        self._start_station_name = value
    @property
    def start_time(self):
        return self._start_time

    @start_time.setter
    def start_time(self, value):
        self._start_time = value
    @property
    def sub_scene(self):
        return self._sub_scene

    @sub_scene.setter
    def sub_scene(self, value):
        self._sub_scene = value
    @property
    def sub_type(self):
        return self._sub_type

    @sub_type.setter
    def sub_type(self, value):
        self._sub_type = value
    @property
    def subject(self):
        return self._subject

    @subject.setter
    def subject(self, value):
        self._subject = value
    @property
    def total_amount(self):
        return self._total_amount

    @total_amount.setter
    def total_amount(self, value):
        self._total_amount = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_agreement_no:
            if hasattr(self.biz_agreement_no, 'to_alipay_dict'):
                params['biz_agreement_no'] = self.biz_agreement_no.to_alipay_dict()
            else:
                params['biz_agreement_no'] = self.biz_agreement_no
        if self.car_type:
            if hasattr(self.car_type, 'to_alipay_dict'):
                params['car_type'] = self.car_type.to_alipay_dict()
            else:
                params['car_type'] = self.car_type
        if self.end_station_name:
            if hasattr(self.end_station_name, 'to_alipay_dict'):
                params['end_station_name'] = self.end_station_name.to_alipay_dict()
            else:
                params['end_station_name'] = self.end_station_name
        if self.end_time:
            if hasattr(self.end_time, 'to_alipay_dict'):
                params['end_time'] = self.end_time.to_alipay_dict()
            else:
                params['end_time'] = self.end_time
        if self.memo:
            if hasattr(self.memo, 'to_alipay_dict'):
                params['memo'] = self.memo.to_alipay_dict()
            else:
                params['memo'] = self.memo
        if self.out_order_id:
            if hasattr(self.out_order_id, 'to_alipay_dict'):
                params['out_order_id'] = self.out_order_id.to_alipay_dict()
            else:
                params['out_order_id'] = self.out_order_id
        if self.plate_color:
            if hasattr(self.plate_color, 'to_alipay_dict'):
                params['plate_color'] = self.plate_color.to_alipay_dict()
            else:
                params['plate_color'] = self.plate_color
        if self.plate_no:
            if hasattr(self.plate_no, 'to_alipay_dict'):
                params['plate_no'] = self.plate_no.to_alipay_dict()
            else:
                params['plate_no'] = self.plate_no
        if self.seller_id:
            if hasattr(self.seller_id, 'to_alipay_dict'):
                params['seller_id'] = self.seller_id.to_alipay_dict()
            else:
                params['seller_id'] = self.seller_id
        if self.start_station_name:
            if hasattr(self.start_station_name, 'to_alipay_dict'):
                params['start_station_name'] = self.start_station_name.to_alipay_dict()
            else:
                params['start_station_name'] = self.start_station_name
        if self.start_time:
            if hasattr(self.start_time, 'to_alipay_dict'):
                params['start_time'] = self.start_time.to_alipay_dict()
            else:
                params['start_time'] = self.start_time
        if self.sub_scene:
            if hasattr(self.sub_scene, 'to_alipay_dict'):
                params['sub_scene'] = self.sub_scene.to_alipay_dict()
            else:
                params['sub_scene'] = self.sub_scene
        if self.sub_type:
            if hasattr(self.sub_type, 'to_alipay_dict'):
                params['sub_type'] = self.sub_type.to_alipay_dict()
            else:
                params['sub_type'] = self.sub_type
        if self.subject:
            if hasattr(self.subject, 'to_alipay_dict'):
                params['subject'] = self.subject.to_alipay_dict()
            else:
                params['subject'] = self.subject
        if self.total_amount:
            if hasattr(self.total_amount, 'to_alipay_dict'):
                params['total_amount'] = self.total_amount.to_alipay_dict()
            else:
                params['total_amount'] = self.total_amount
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayCommerceTransportEtcSettlementApplyModel()
        if 'biz_agreement_no' in d:
            o.biz_agreement_no = d['biz_agreement_no']
        if 'car_type' in d:
            o.car_type = d['car_type']
        if 'end_station_name' in d:
            o.end_station_name = d['end_station_name']
        if 'end_time' in d:
            o.end_time = d['end_time']
        if 'memo' in d:
            o.memo = d['memo']
        if 'out_order_id' in d:
            o.out_order_id = d['out_order_id']
        if 'plate_color' in d:
            o.plate_color = d['plate_color']
        if 'plate_no' in d:
            o.plate_no = d['plate_no']
        if 'seller_id' in d:
            o.seller_id = d['seller_id']
        if 'start_station_name' in d:
            o.start_station_name = d['start_station_name']
        if 'start_time' in d:
            o.start_time = d['start_time']
        if 'sub_scene' in d:
            o.sub_scene = d['sub_scene']
        if 'sub_type' in d:
            o.sub_type = d['sub_type']
        if 'subject' in d:
            o.subject = d['subject']
        if 'total_amount' in d:
            o.total_amount = d['total_amount']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AnttechBlockchainDefinDataserviceCropbaseBatchqueryModel(object):

    def __init__(self):
        self._crop_code = None
        self._growth_strength = None
        self._is_certain_risk = None
        self._is_growth_warn = None
        self._is_harvested = None
        self._is_high_temperature_risk = None
        self._is_low_temperature_risk = None
        self._is_rainstorm_risk = None
        self._is_soil_moisture_risk = None
        self._need_crop_only = None
        self._page_no = None
        self._page_size = None
        self._region_codes = None
        self._region_group_code = None

    @property
    def crop_code(self):
        return self._crop_code

    @crop_code.setter
    def crop_code(self, value):
        self._crop_code = value
    @property
    def growth_strength(self):
        return self._growth_strength

    @growth_strength.setter
    def growth_strength(self, value):
        self._growth_strength = value
    @property
    def is_certain_risk(self):
        return self._is_certain_risk

    @is_certain_risk.setter
    def is_certain_risk(self, value):
        self._is_certain_risk = value
    @property
    def is_growth_warn(self):
        return self._is_growth_warn

    @is_growth_warn.setter
    def is_growth_warn(self, value):
        self._is_growth_warn = value
    @property
    def is_harvested(self):
        return self._is_harvested

    @is_harvested.setter
    def is_harvested(self, value):
        self._is_harvested = value
    @property
    def is_high_temperature_risk(self):
        return self._is_high_temperature_risk

    @is_high_temperature_risk.setter
    def is_high_temperature_risk(self, value):
        self._is_high_temperature_risk = value
    @property
    def is_low_temperature_risk(self):
        return self._is_low_temperature_risk

    @is_low_temperature_risk.setter
    def is_low_temperature_risk(self, value):
        self._is_low_temperature_risk = value
    @property
    def is_rainstorm_risk(self):
        return self._is_rainstorm_risk

    @is_rainstorm_risk.setter
    def is_rainstorm_risk(self, value):
        self._is_rainstorm_risk = value
    @property
    def is_soil_moisture_risk(self):
        return self._is_soil_moisture_risk

    @is_soil_moisture_risk.setter
    def is_soil_moisture_risk(self, value):
        self._is_soil_moisture_risk = value
    @property
    def need_crop_only(self):
        return self._need_crop_only

    @need_crop_only.setter
    def need_crop_only(self, value):
        self._need_crop_only = value
    @property
    def page_no(self):
        return self._page_no

    @page_no.setter
    def page_no(self, value):
        self._page_no = value
    @property
    def page_size(self):
        return self._page_size

    @page_size.setter
    def page_size(self, value):
        self._page_size = value
    @property
    def region_codes(self):
        return self._region_codes

    @region_codes.setter
    def region_codes(self, value):
        if isinstance(value, list):
            self._region_codes = list()
            for i in value:
                self._region_codes.append(i)
    @property
    def region_group_code(self):
        return self._region_group_code

    @region_group_code.setter
    def region_group_code(self, value):
        self._region_group_code = value


    def to_alipay_dict(self):
        params = dict()
        if self.crop_code:
            if hasattr(self.crop_code, 'to_alipay_dict'):
                params['crop_code'] = self.crop_code.to_alipay_dict()
            else:
                params['crop_code'] = self.crop_code
        if self.growth_strength:
            if hasattr(self.growth_strength, 'to_alipay_dict'):
                params['growth_strength'] = self.growth_strength.to_alipay_dict()
            else:
                params['growth_strength'] = self.growth_strength
        if self.is_certain_risk:
            if hasattr(self.is_certain_risk, 'to_alipay_dict'):
                params['is_certain_risk'] = self.is_certain_risk.to_alipay_dict()
            else:
                params['is_certain_risk'] = self.is_certain_risk
        if self.is_growth_warn:
            if hasattr(self.is_growth_warn, 'to_alipay_dict'):
                params['is_growth_warn'] = self.is_growth_warn.to_alipay_dict()
            else:
                params['is_growth_warn'] = self.is_growth_warn
        if self.is_harvested:
            if hasattr(self.is_harvested, 'to_alipay_dict'):
                params['is_harvested'] = self.is_harvested.to_alipay_dict()
            else:
                params['is_harvested'] = self.is_harvested
        if self.is_high_temperature_risk:
            if hasattr(self.is_high_temperature_risk, 'to_alipay_dict'):
                params['is_high_temperature_risk'] = self.is_high_temperature_risk.to_alipay_dict()
            else:
                params['is_high_temperature_risk'] = self.is_high_temperature_risk
        if self.is_low_temperature_risk:
            if hasattr(self.is_low_temperature_risk, 'to_alipay_dict'):
                params['is_low_temperature_risk'] = self.is_low_temperature_risk.to_alipay_dict()
            else:
                params['is_low_temperature_risk'] = self.is_low_temperature_risk
        if self.is_rainstorm_risk:
            if hasattr(self.is_rainstorm_risk, 'to_alipay_dict'):
                params['is_rainstorm_risk'] = self.is_rainstorm_risk.to_alipay_dict()
            else:
                params['is_rainstorm_risk'] = self.is_rainstorm_risk
        if self.is_soil_moisture_risk:
            if hasattr(self.is_soil_moisture_risk, 'to_alipay_dict'):
                params['is_soil_moisture_risk'] = self.is_soil_moisture_risk.to_alipay_dict()
            else:
                params['is_soil_moisture_risk'] = self.is_soil_moisture_risk
        if self.need_crop_only:
            if hasattr(self.need_crop_only, 'to_alipay_dict'):
                params['need_crop_only'] = self.need_crop_only.to_alipay_dict()
            else:
                params['need_crop_only'] = self.need_crop_only
        if self.page_no:
            if hasattr(self.page_no, 'to_alipay_dict'):
                params['page_no'] = self.page_no.to_alipay_dict()
            else:
                params['page_no'] = self.page_no
        if self.page_size:
            if hasattr(self.page_size, 'to_alipay_dict'):
                params['page_size'] = self.page_size.to_alipay_dict()
            else:
                params['page_size'] = self.page_size
        if self.region_codes:
            if isinstance(self.region_codes, list):
                for i in range(0, len(self.region_codes)):
                    element = self.region_codes[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.region_codes[i] = element.to_alipay_dict()
            if hasattr(self.region_codes, 'to_alipay_dict'):
                params['region_codes'] = self.region_codes.to_alipay_dict()
            else:
                params['region_codes'] = self.region_codes
        if self.region_group_code:
            if hasattr(self.region_group_code, 'to_alipay_dict'):
                params['region_group_code'] = self.region_group_code.to_alipay_dict()
            else:
                params['region_group_code'] = self.region_group_code
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AnttechBlockchainDefinDataserviceCropbaseBatchqueryModel()
        if 'crop_code' in d:
            o.crop_code = d['crop_code']
        if 'growth_strength' in d:
            o.growth_strength = d['growth_strength']
        if 'is_certain_risk' in d:
            o.is_certain_risk = d['is_certain_risk']
        if 'is_growth_warn' in d:
            o.is_growth_warn = d['is_growth_warn']
        if 'is_harvested' in d:
            o.is_harvested = d['is_harvested']
        if 'is_high_temperature_risk' in d:
            o.is_high_temperature_risk = d['is_high_temperature_risk']
        if 'is_low_temperature_risk' in d:
            o.is_low_temperature_risk = d['is_low_temperature_risk']
        if 'is_rainstorm_risk' in d:
            o.is_rainstorm_risk = d['is_rainstorm_risk']
        if 'is_soil_moisture_risk' in d:
            o.is_soil_moisture_risk = d['is_soil_moisture_risk']
        if 'need_crop_only' in d:
            o.need_crop_only = d['need_crop_only']
        if 'page_no' in d:
            o.page_no = d['page_no']
        if 'page_size' in d:
            o.page_size = d['page_size']
        if 'region_codes' in d:
            o.region_codes = d['region_codes']
        if 'region_group_code' in d:
            o.region_group_code = d['region_group_code']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEbppCommunityServiceOfflineModel(object):

    def __init__(self):
        self._community_short_name = None
        self._memo = None
        self._service_type = None

    @property
    def community_short_name(self):
        return self._community_short_name

    @community_short_name.setter
    def community_short_name(self, value):
        self._community_short_name = value
    @property
    def memo(self):
        return self._memo

    @memo.setter
    def memo(self, value):
        self._memo = value
    @property
    def service_type(self):
        return self._service_type

    @service_type.setter
    def service_type(self, value):
        self._service_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.community_short_name:
            if hasattr(self.community_short_name, 'to_alipay_dict'):
                params['community_short_name'] = self.community_short_name.to_alipay_dict()
            else:
                params['community_short_name'] = self.community_short_name
        if self.memo:
            if hasattr(self.memo, 'to_alipay_dict'):
                params['memo'] = self.memo.to_alipay_dict()
            else:
                params['memo'] = self.memo
        if self.service_type:
            if hasattr(self.service_type, 'to_alipay_dict'):
                params['service_type'] = self.service_type.to_alipay_dict()
            else:
                params['service_type'] = self.service_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEbppCommunityServiceOfflineModel()
        if 'community_short_name' in d:
            o.community_short_name = d['community_short_name']
        if 'memo' in d:
            o.memo = d['memo']
        if 'service_type' in d:
            o.service_type = d['service_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenIotmbsRoomUnbindModel(object):

    def __init__(self):
        self._dev_id = None
        self._project_id = None

    @property
    def dev_id(self):
        return self._dev_id

    @dev_id.setter
    def dev_id(self, value):
        self._dev_id = value
    @property
    def project_id(self):
        return self._project_id

    @project_id.setter
    def project_id(self, value):
        self._project_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.dev_id:
            if hasattr(self.dev_id, 'to_alipay_dict'):
                params['dev_id'] = self.dev_id.to_alipay_dict()
            else:
                params['dev_id'] = self.dev_id
        if self.project_id:
            if hasattr(self.project_id, 'to_alipay_dict'):
                params['project_id'] = self.project_id.to_alipay_dict()
            else:
                params['project_id'] = self.project_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenIotmbsRoomUnbindModel()
        if 'dev_id' in d:
            o.dev_id = d['dev_id']
        if 'project_id' in d:
            o.project_id = d['project_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.CertFields import CertFields


class CertAuditResult(object):

    def __init__(self):
        self._authority_check_retcode = None
        self._authority_check_retmessage = None
        self._authority_check_suggest = None
        self._cert_face_suggest = None
        self._compliance_suggest = None
        self._ocr = None
        self._ocr_check_suggest = None

    @property
    def authority_check_retcode(self):
        return self._authority_check_retcode

    @authority_check_retcode.setter
    def authority_check_retcode(self, value):
        self._authority_check_retcode = value
    @property
    def authority_check_retmessage(self):
        return self._authority_check_retmessage

    @authority_check_retmessage.setter
    def authority_check_retmessage(self, value):
        self._authority_check_retmessage = value
    @property
    def authority_check_suggest(self):
        return self._authority_check_suggest

    @authority_check_suggest.setter
    def authority_check_suggest(self, value):
        self._authority_check_suggest = value
    @property
    def cert_face_suggest(self):
        return self._cert_face_suggest

    @cert_face_suggest.setter
    def cert_face_suggest(self, value):
        self._cert_face_suggest = value
    @property
    def compliance_suggest(self):
        return self._compliance_suggest

    @compliance_suggest.setter
    def compliance_suggest(self, value):
        self._compliance_suggest = value
    @property
    def ocr(self):
        return self._ocr

    @ocr.setter
    def ocr(self, value):
        if isinstance(value, CertFields):
            self._ocr = value
        else:
            self._ocr = CertFields.from_alipay_dict(value)
    @property
    def ocr_check_suggest(self):
        return self._ocr_check_suggest

    @ocr_check_suggest.setter
    def ocr_check_suggest(self, value):
        self._ocr_check_suggest = value


    def to_alipay_dict(self):
        params = dict()
        if self.authority_check_retcode:
            if hasattr(self.authority_check_retcode, 'to_alipay_dict'):
                params['authority_check_retcode'] = self.authority_check_retcode.to_alipay_dict()
            else:
                params['authority_check_retcode'] = self.authority_check_retcode
        if self.authority_check_retmessage:
            if hasattr(self.authority_check_retmessage, 'to_alipay_dict'):
                params['authority_check_retmessage'] = self.authority_check_retmessage.to_alipay_dict()
            else:
                params['authority_check_retmessage'] = self.authority_check_retmessage
        if self.authority_check_suggest:
            if hasattr(self.authority_check_suggest, 'to_alipay_dict'):
                params['authority_check_suggest'] = self.authority_check_suggest.to_alipay_dict()
            else:
                params['authority_check_suggest'] = self.authority_check_suggest
        if self.cert_face_suggest:
            if hasattr(self.cert_face_suggest, 'to_alipay_dict'):
                params['cert_face_suggest'] = self.cert_face_suggest.to_alipay_dict()
            else:
                params['cert_face_suggest'] = self.cert_face_suggest
        if self.compliance_suggest:
            if hasattr(self.compliance_suggest, 'to_alipay_dict'):
                params['compliance_suggest'] = self.compliance_suggest.to_alipay_dict()
            else:
                params['compliance_suggest'] = self.compliance_suggest
        if self.ocr:
            if hasattr(self.ocr, 'to_alipay_dict'):
                params['ocr'] = self.ocr.to_alipay_dict()
            else:
                params['ocr'] = self.ocr
        if self.ocr_check_suggest:
            if hasattr(self.ocr_check_suggest, 'to_alipay_dict'):
                params['ocr_check_suggest'] = self.ocr_check_suggest.to_alipay_dict()
            else:
                params['ocr_check_suggest'] = self.ocr_check_suggest
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = CertAuditResult()
        if 'authority_check_retcode' in d:
            o.authority_check_retcode = d['authority_check_retcode']
        if 'authority_check_retmessage' in d:
            o.authority_check_retmessage = d['authority_check_retmessage']
        if 'authority_check_suggest' in d:
            o.authority_check_suggest = d['authority_check_suggest']
        if 'cert_face_suggest' in d:
            o.cert_face_suggest = d['cert_face_suggest']
        if 'compliance_suggest' in d:
            o.compliance_suggest = d['compliance_suggest']
        if 'ocr' in d:
            o.ocr = d['ocr']
        if 'ocr_check_suggest' in d:
            o.ocr_check_suggest = d['ocr_check_suggest']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenAppRateDataSyncModel(object):

    def __init__(self):
        self._biz_no = None
        self._control_status = None
        self._in_biz_account = None
        self._oper_type = None
        self._out_biz_account = None
        self._rate_id = None
        self._score = None
        self._shop_id = None
        self._source = None
        self._type = None

    @property
    def biz_no(self):
        return self._biz_no

    @biz_no.setter
    def biz_no(self, value):
        self._biz_no = value
    @property
    def control_status(self):
        return self._control_status

    @control_status.setter
    def control_status(self, value):
        self._control_status = value
    @property
    def in_biz_account(self):
        return self._in_biz_account

    @in_biz_account.setter
    def in_biz_account(self, value):
        self._in_biz_account = value
    @property
    def oper_type(self):
        return self._oper_type

    @oper_type.setter
    def oper_type(self, value):
        self._oper_type = value
    @property
    def out_biz_account(self):
        return self._out_biz_account

    @out_biz_account.setter
    def out_biz_account(self, value):
        self._out_biz_account = value
    @property
    def rate_id(self):
        return self._rate_id

    @rate_id.setter
    def rate_id(self, value):
        self._rate_id = value
    @property
    def score(self):
        return self._score

    @score.setter
    def score(self, value):
        self._score = value
    @property
    def shop_id(self):
        return self._shop_id

    @shop_id.setter
    def shop_id(self, value):
        self._shop_id = value
    @property
    def source(self):
        return self._source

    @source.setter
    def source(self, value):
        self._source = value
    @property
    def type(self):
        return self._type

    @type.setter
    def type(self, value):
        self._type = value


    def to_alipay_dict(self):
        params = dict()
        if self.biz_no:
            if hasattr(self.biz_no, 'to_alipay_dict'):
                params['biz_no'] = self.biz_no.to_alipay_dict()
            else:
                params['biz_no'] = self.biz_no
        if self.control_status:
            if hasattr(self.control_status, 'to_alipay_dict'):
                params['control_status'] = self.control_status.to_alipay_dict()
            else:
                params['control_status'] = self.control_status
        if self.in_biz_account:
            if hasattr(self.in_biz_account, 'to_alipay_dict'):
                params['in_biz_account'] = self.in_biz_account.to_alipay_dict()
            else:
                params['in_biz_account'] = self.in_biz_account
        if self.oper_type:
            if hasattr(self.oper_type, 'to_alipay_dict'):
                params['oper_type'] = self.oper_type.to_alipay_dict()
            else:
                params['oper_type'] = self.oper_type
        if self.out_biz_account:
            if hasattr(self.out_biz_account, 'to_alipay_dict'):
                params['out_biz_account'] = self.out_biz_account.to_alipay_dict()
            else:
                params['out_biz_account'] = self.out_biz_account
        if self.rate_id:
            if hasattr(self.rate_id, 'to_alipay_dict'):
                params['rate_id'] = self.rate_id.to_alipay_dict()
            else:
                params['rate_id'] = self.rate_id
        if self.score:
            if hasattr(self.score, 'to_alipay_dict'):
                params['score'] = self.score.to_alipay_dict()
            else:
                params['score'] = self.score
        if self.shop_id:
            if hasattr(self.shop_id, 'to_alipay_dict'):
                params['shop_id'] = self.shop_id.to_alipay_dict()
            else:
                params['shop_id'] = self.shop_id
        if self.source:
            if hasattr(self.source, 'to_alipay_dict'):
                params['source'] = self.source.to_alipay_dict()
            else:
                params['source'] = self.source
        if self.type:
            if hasattr(self.type, 'to_alipay_dict'):
                params['type'] = self.type.to_alipay_dict()
            else:
                params['type'] = self.type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenAppRateDataSyncModel()
        if 'biz_no' in d:
            o.biz_no = d['biz_no']
        if 'control_status' in d:
            o.control_status = d['control_status']
        if 'in_biz_account' in d:
            o.in_biz_account = d['in_biz_account']
        if 'oper_type' in d:
            o.oper_type = d['oper_type']
        if 'out_biz_account' in d:
            o.out_biz_account = d['out_biz_account']
        if 'rate_id' in d:
            o.rate_id = d['rate_id']
        if 'score' in d:
            o.score = d['score']
        if 'shop_id' in d:
            o.shop_id = d['shop_id']
        if 'source' in d:
            o.source = d['source']
        if 'type' in d:
            o.type = d['type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.DeliveryFullSendConfig import DeliveryFullSendConfig
from alipay.aop.api.domain.DeliverySingleSendConfig import DeliverySingleSendConfig


class DeliveryPlayConfig(object):

    def __init__(self):
        self._delivery_full_send_config = None
        self._delivery_single_send_config = None

    @property
    def delivery_full_send_config(self):
        return self._delivery_full_send_config

    @delivery_full_send_config.setter
    def delivery_full_send_config(self, value):
        if isinstance(value, DeliveryFullSendConfig):
            self._delivery_full_send_config = value
        else:
            self._delivery_full_send_config = DeliveryFullSendConfig.from_alipay_dict(value)
    @property
    def delivery_single_send_config(self):
        return self._delivery_single_send_config

    @delivery_single_send_config.setter
    def delivery_single_send_config(self, value):
        if isinstance(value, DeliverySingleSendConfig):
            self._delivery_single_send_config = value
        else:
            self._delivery_single_send_config = DeliverySingleSendConfig.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.delivery_full_send_config:
            if hasattr(self.delivery_full_send_config, 'to_alipay_dict'):
                params['delivery_full_send_config'] = self.delivery_full_send_config.to_alipay_dict()
            else:
                params['delivery_full_send_config'] = self.delivery_full_send_config
        if self.delivery_single_send_config:
            if hasattr(self.delivery_single_send_config, 'to_alipay_dict'):
                params['delivery_single_send_config'] = self.delivery_single_send_config.to_alipay_dict()
            else:
                params['delivery_single_send_config'] = self.delivery_single_send_config
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = DeliveryPlayConfig()
        if 'delivery_full_send_config' in d:
            o.delivery_full_send_config = d['delivery_full_send_config']
        if 'delivery_single_send_config' in d:
            o.delivery_single_send_config = d['delivery_single_send_config']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class BizFundSettleSummary(object):

    def __init__(self):
        self._charge = None

    @property
    def charge(self):
        return self._charge

    @charge.setter
    def charge(self, value):
        self._charge = value


    def to_alipay_dict(self):
        params = dict()
        if self.charge:
            if hasattr(self.charge, 'to_alipay_dict'):
                params['charge'] = self.charge.to_alipay_dict()
            else:
                params['charge'] = self.charge
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = BizFundSettleSummary()
        if 'charge' in d:
            o.charge = d['charge']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayFundTransInvoiceStatusModifyModel(object):

    def __init__(self):
        self._invoice_code = None
        self._invoice_number = None
        self._payer_id_type = None
        self._payer_id_value = None
        self._status = None
        self._user_id = None
        self._verify = None

    @property
    def invoice_code(self):
        return self._invoice_code

    @invoice_code.setter
    def invoice_code(self, value):
        self._invoice_code = value
    @property
    def invoice_number(self):
        return self._invoice_number

    @invoice_number.setter
    def invoice_number(self, value):
        self._invoice_number = value
    @property
    def payer_id_type(self):
        return self._payer_id_type

    @payer_id_type.setter
    def payer_id_type(self, value):
        self._payer_id_type = value
    @property
    def payer_id_value(self):
        return self._payer_id_value

    @payer_id_value.setter
    def payer_id_value(self, value):
        self._payer_id_value = value
    @property
    def status(self):
        return self._status

    @status.setter
    def status(self, value):
        self._status = value
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value
    @property
    def verify(self):
        return self._verify

    @verify.setter
    def verify(self, value):
        self._verify = value


    def to_alipay_dict(self):
        params = dict()
        if self.invoice_code:
            if hasattr(self.invoice_code, 'to_alipay_dict'):
                params['invoice_code'] = self.invoice_code.to_alipay_dict()
            else:
                params['invoice_code'] = self.invoice_code
        if self.invoice_number:
            if hasattr(self.invoice_number, 'to_alipay_dict'):
                params['invoice_number'] = self.invoice_number.to_alipay_dict()
            else:
                params['invoice_number'] = self.invoice_number
        if self.payer_id_type:
            if hasattr(self.payer_id_type, 'to_alipay_dict'):
                params['payer_id_type'] = self.payer_id_type.to_alipay_dict()
            else:
                params['payer_id_type'] = self.payer_id_type
        if self.payer_id_value:
            if hasattr(self.payer_id_value, 'to_alipay_dict'):
                params['payer_id_value'] = self.payer_id_value.to_alipay_dict()
            else:
                params['payer_id_value'] = self.payer_id_value
        if self.status:
            if hasattr(self.status, 'to_alipay_dict'):
                params['status'] = self.status.to_alipay_dict()
            else:
                params['status'] = self.status
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        if self.verify:
            if hasattr(self.verify, 'to_alipay_dict'):
                params['verify'] = self.verify.to_alipay_dict()
            else:
                params['verify'] = self.verify
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayFundTransInvoiceStatusModifyModel()
        if 'invoice_code' in d:
            o.invoice_code = d['invoice_code']
        if 'invoice_number' in d:
            o.invoice_number = d['invoice_number']
        if 'payer_id_type' in d:
            o.payer_id_type = d['payer_id_type']
        if 'payer_id_value' in d:
            o.payer_id_value = d['payer_id_value']
        if 'status' in d:
            o.status = d['status']
        if 'user_id' in d:
            o.user_id = d['user_id']
        if 'verify' in d:
            o.verify = d['verify']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.Participant import Participant


class AlipayFundBizorderCreateModel(object):

    def __init__(self):
        self._business_params = None
        self._order_amount = None
        self._order_title = None
        self._out_biz_no = None
        self._partner_user_id = None
        self._payee_info = None

    @property
    def business_params(self):
        return self._business_params

    @business_params.setter
    def business_params(self, value):
        self._business_params = value
    @property
    def order_amount(self):
        return self._order_amount

    @order_amount.setter
    def order_amount(self, value):
        self._order_amount = value
    @property
    def order_title(self):
        return self._order_title

    @order_title.setter
    def order_title(self, value):
        self._order_title = value
    @property
    def out_biz_no(self):
        return self._out_biz_no

    @out_biz_no.setter
    def out_biz_no(self, value):
        self._out_biz_no = value
    @property
    def partner_user_id(self):
        return self._partner_user_id

    @partner_user_id.setter
    def partner_user_id(self, value):
        self._partner_user_id = value
    @property
    def payee_info(self):
        return self._payee_info

    @payee_info.setter
    def payee_info(self, value):
        if isinstance(value, Participant):
            self._payee_info = value
        else:
            self._payee_info = Participant.from_alipay_dict(value)


    def to_alipay_dict(self):
        params = dict()
        if self.business_params:
            if hasattr(self.business_params, 'to_alipay_dict'):
                params['business_params'] = self.business_params.to_alipay_dict()
            else:
                params['business_params'] = self.business_params
        if self.order_amount:
            if hasattr(self.order_amount, 'to_alipay_dict'):
                params['order_amount'] = self.order_amount.to_alipay_dict()
            else:
                params['order_amount'] = self.order_amount
        if self.order_title:
            if hasattr(self.order_title, 'to_alipay_dict'):
                params['order_title'] = self.order_title.to_alipay_dict()
            else:
                params['order_title'] = self.order_title
        if self.out_biz_no:
            if hasattr(self.out_biz_no, 'to_alipay_dict'):
                params['out_biz_no'] = self.out_biz_no.to_alipay_dict()
            else:
                params['out_biz_no'] = self.out_biz_no
        if self.partner_user_id:
            if hasattr(self.partner_user_id, 'to_alipay_dict'):
                params['partner_user_id'] = self.partner_user_id.to_alipay_dict()
            else:
                params['partner_user_id'] = self.partner_user_id
        if self.payee_info:
            if hasattr(self.payee_info, 'to_alipay_dict'):
                params['payee_info'] = self.payee_info.to_alipay_dict()
            else:
                params['payee_info'] = self.payee_info
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayFundBizorderCreateModel()
        if 'business_params' in d:
            o.business_params = d['business_params']
        if 'order_amount' in d:
            o.order_amount = d['order_amount']
        if 'order_title' in d:
            o.order_title = d['order_title']
        if 'out_biz_no' in d:
            o.out_biz_no = d['out_biz_no']
        if 'partner_user_id' in d:
            o.partner_user_id = d['partner_user_id']
        if 'payee_info' in d:
            o.payee_info = d['payee_info']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AntMerchantExpandApprecommendAccountQueryResponse(AlipayResponse):

    def __init__(self):
        super(AntMerchantExpandApprecommendAccountQueryResponse, self).__init__()
        self._list = None
        self._page_number = None
        self._page_size = None
        self._total_pages = None
        self._total_size = None

    @property
    def list(self):
        return self._list

    @list.setter
    def list(self, value):
        if isinstance(value, list):
            self._list = list()
            for i in value:
                self._list.append(i)
    @property
    def page_number(self):
        return self._page_number

    @page_number.setter
    def page_number(self, value):
        self._page_number = value
    @property
    def page_size(self):
        return self._page_size

    @page_size.setter
    def page_size(self, value):
        self._page_size = value
    @property
    def total_pages(self):
        return self._total_pages

    @total_pages.setter
    def total_pages(self, value):
        self._total_pages = value
    @property
    def total_size(self):
        return self._total_size

    @total_size.setter
    def total_size(self, value):
        self._total_size = value

    def parse_response_content(self, response_content):
        response = super(AntMerchantExpandApprecommendAccountQueryResponse, self).parse_response_content(response_content)
        if 'list' in response:
            self.list = response['list']
        if 'page_number' in response:
            self.page_number = response['page_number']
        if 'page_size' in response:
            self.page_size = response['page_size']
        if 'total_pages' in response:
            self.total_pages = response['total_pages']
        if 'total_size' in response:
            self.total_size = response['total_size']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class Invoice(object):

    def __init__(self):
        self._email = None
        self._invoice_content = None
        self._invoice_fee = None
        self._invoice_title = None
        self._invoice_type = None
        self._phone = None
        self._receiver = None
        self._tax_number = None
        self._title_type = None

    @property
    def email(self):
        return self._email

    @email.setter
    def email(self, value):
        self._email = value
    @property
    def invoice_content(self):
        return self._invoice_content

    @invoice_content.setter
    def invoice_content(self, value):
        self._invoice_content = value
    @property
    def invoice_fee(self):
        return self._invoice_fee

    @invoice_fee.setter
    def invoice_fee(self, value):
        self._invoice_fee = value
    @property
    def invoice_title(self):
        return self._invoice_title

    @invoice_title.setter
    def invoice_title(self, value):
        self._invoice_title = value
    @property
    def invoice_type(self):
        return self._invoice_type

    @invoice_type.setter
    def invoice_type(self, value):
        self._invoice_type = value
    @property
    def phone(self):
        return self._phone

    @phone.setter
    def phone(self, value):
        self._phone = value
    @property
    def receiver(self):
        return self._receiver

    @receiver.setter
    def receiver(self, value):
        self._receiver = value
    @property
    def tax_number(self):
        return self._tax_number

    @tax_number.setter
    def tax_number(self, value):
        self._tax_number = value
    @property
    def title_type(self):
        return self._title_type

    @title_type.setter
    def title_type(self, value):
        self._title_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.email:
            if hasattr(self.email, 'to_alipay_dict'):
                params['email'] = self.email.to_alipay_dict()
            else:
                params['email'] = self.email
        if self.invoice_content:
            if hasattr(self.invoice_content, 'to_alipay_dict'):
                params['invoice_content'] = self.invoice_content.to_alipay_dict()
            else:
                params['invoice_content'] = self.invoice_content
        if self.invoice_fee:
            if hasattr(self.invoice_fee, 'to_alipay_dict'):
                params['invoice_fee'] = self.invoice_fee.to_alipay_dict()
            else:
                params['invoice_fee'] = self.invoice_fee
        if self.invoice_title:
            if hasattr(self.invoice_title, 'to_alipay_dict'):
                params['invoice_title'] = self.invoice_title.to_alipay_dict()
            else:
                params['invoice_title'] = self.invoice_title
        if self.invoice_type:
            if hasattr(self.invoice_type, 'to_alipay_dict'):
                params['invoice_type'] = self.invoice_type.to_alipay_dict()
            else:
                params['invoice_type'] = self.invoice_type
        if self.phone:
            if hasattr(self.phone, 'to_alipay_dict'):
                params['phone'] = self.phone.to_alipay_dict()
            else:
                params['phone'] = self.phone
        if self.receiver:
            if hasattr(self.receiver, 'to_alipay_dict'):
                params['receiver'] = self.receiver.to_alipay_dict()
            else:
                params['receiver'] = self.receiver
        if self.tax_number:
            if hasattr(self.tax_number, 'to_alipay_dict'):
                params['tax_number'] = self.tax_number.to_alipay_dict()
            else:
                params['tax_number'] = self.tax_number
        if self.title_type:
            if hasattr(self.title_type, 'to_alipay_dict'):
                params['title_type'] = self.title_type.to_alipay_dict()
            else:
                params['title_type'] = self.title_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = Invoice()
        if 'email' in d:
            o.email = d['email']
        if 'invoice_content' in d:
            o.invoice_content = d['invoice_content']
        if 'invoice_fee' in d:
            o.invoice_fee = d['invoice_fee']
        if 'invoice_title' in d:
            o.invoice_title = d['invoice_title']
        if 'invoice_type' in d:
            o.invoice_type = d['invoice_type']
        if 'phone' in d:
            o.phone = d['phone']
        if 'receiver' in d:
            o.receiver = d['receiver']
        if 'tax_number' in d:
            o.tax_number = d['tax_number']
        if 'title_type' in d:
            o.title_type = d['title_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayCommerceOperationBsInviteConsultResponse(AlipayResponse):

    def __init__(self):
        super(AlipayCommerceOperationBsInviteConsultResponse, self).__init__()
        self._invitable = None

    @property
    def invitable(self):
        return self._invitable

    @invitable.setter
    def invitable(self, value):
        self._invitable = value

    def parse_response_content(self, response_content):
        response = super(AlipayCommerceOperationBsInviteConsultResponse, self).parse_response_content(response_content)
        if 'invitable' in response:
            self.invitable = response['invitable']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *
from alipay.aop.api.domain.ItemConsultInfo import ItemConsultInfo


class ItemPromoInfo(object):

    def __init__(self):
        self._item_consult_list = None
        self._item_cover_pic = None
        self._item_desc = None
        self._item_detail_pic_list = None
        self._item_name = None

    @property
    def item_consult_list(self):
        return self._item_consult_list

    @item_consult_list.setter
    def item_consult_list(self, value):
        if isinstance(value, list):
            self._item_consult_list = list()
            for i in value:
                if isinstance(i, ItemConsultInfo):
                    self._item_consult_list.append(i)
                else:
                    self._item_consult_list.append(ItemConsultInfo.from_alipay_dict(i))
    @property
    def item_cover_pic(self):
        return self._item_cover_pic

    @item_cover_pic.setter
    def item_cover_pic(self, value):
        self._item_cover_pic = value
    @property
    def item_desc(self):
        return self._item_desc

    @item_desc.setter
    def item_desc(self, value):
        self._item_desc = value
    @property
    def item_detail_pic_list(self):
        return self._item_detail_pic_list

    @item_detail_pic_list.setter
    def item_detail_pic_list(self, value):
        if isinstance(value, list):
            self._item_detail_pic_list = list()
            for i in value:
                self._item_detail_pic_list.append(i)
    @property
    def item_name(self):
        return self._item_name

    @item_name.setter
    def item_name(self, value):
        self._item_name = value


    def to_alipay_dict(self):
        params = dict()
        if self.item_consult_list:
            if isinstance(self.item_consult_list, list):
                for i in range(0, len(self.item_consult_list)):
                    element = self.item_consult_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.item_consult_list[i] = element.to_alipay_dict()
            if hasattr(self.item_consult_list, 'to_alipay_dict'):
                params['item_consult_list'] = self.item_consult_list.to_alipay_dict()
            else:
                params['item_consult_list'] = self.item_consult_list
        if self.item_cover_pic:
            if hasattr(self.item_cover_pic, 'to_alipay_dict'):
                params['item_cover_pic'] = self.item_cover_pic.to_alipay_dict()
            else:
                params['item_cover_pic'] = self.item_cover_pic
        if self.item_desc:
            if hasattr(self.item_desc, 'to_alipay_dict'):
                params['item_desc'] = self.item_desc.to_alipay_dict()
            else:
                params['item_desc'] = self.item_desc
        if self.item_detail_pic_list:
            if isinstance(self.item_detail_pic_list, list):
                for i in range(0, len(self.item_detail_pic_list)):
                    element = self.item_detail_pic_list[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.item_detail_pic_list[i] = element.to_alipay_dict()
            if hasattr(self.item_detail_pic_list, 'to_alipay_dict'):
                params['item_detail_pic_list'] = self.item_detail_pic_list.to_alipay_dict()
            else:
                params['item_detail_pic_list'] = self.item_detail_pic_list
        if self.item_name:
            if hasattr(self.item_name, 'to_alipay_dict'):
                params['item_name'] = self.item_name.to_alipay_dict()
            else:
                params['item_name'] = self.item_name
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = ItemPromoInfo()
        if 'item_consult_list' in d:
            o.item_consult_list = d['item_consult_list']
        if 'item_cover_pic' in d:
            o.item_cover_pic = d['item_cover_pic']
        if 'item_desc' in d:
            o.item_desc = d['item_desc']
        if 'item_detail_pic_list' in d:
            o.item_detail_pic_list = d['item_detail_pic_list']
        if 'item_name' in d:
            o.item_name = d['item_name']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayMarketingCampaignTaskQueryModel(object):

    def __init__(self):
        self._open_id = None
        self._task_cen_id = None
        self._task_ids = None
        self._user_id = None

    @property
    def open_id(self):
        return self._open_id

    @open_id.setter
    def open_id(self, value):
        self._open_id = value
    @property
    def task_cen_id(self):
        return self._task_cen_id

    @task_cen_id.setter
    def task_cen_id(self, value):
        self._task_cen_id = value
    @property
    def task_ids(self):
        return self._task_ids

    @task_ids.setter
    def task_ids(self, value):
        if isinstance(value, list):
            self._task_ids = list()
            for i in value:
                self._task_ids.append(i)
    @property
    def user_id(self):
        return self._user_id

    @user_id.setter
    def user_id(self, value):
        self._user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.open_id:
            if hasattr(self.open_id, 'to_alipay_dict'):
                params['open_id'] = self.open_id.to_alipay_dict()
            else:
                params['open_id'] = self.open_id
        if self.task_cen_id:
            if hasattr(self.task_cen_id, 'to_alipay_dict'):
                params['task_cen_id'] = self.task_cen_id.to_alipay_dict()
            else:
                params['task_cen_id'] = self.task_cen_id
        if self.task_ids:
            if isinstance(self.task_ids, list):
                for i in range(0, len(self.task_ids)):
                    element = self.task_ids[i]
                    if hasattr(element, 'to_alipay_dict'):
                        self.task_ids[i] = element.to_alipay_dict()
            if hasattr(self.task_ids, 'to_alipay_dict'):
                params['task_ids'] = self.task_ids.to_alipay_dict()
            else:
                params['task_ids'] = self.task_ids
        if self.user_id:
            if hasattr(self.user_id, 'to_alipay_dict'):
                params['user_id'] = self.user_id.to_alipay_dict()
            else:
                params['user_id'] = self.user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayMarketingCampaignTaskQueryModel()
        if 'open_id' in d:
            o.open_id = d['open_id']
        if 'task_cen_id' in d:
            o.task_cen_id = d['task_cen_id']
        if 'task_ids' in d:
            o.task_ids = d['task_ids']
        if 'user_id' in d:
            o.user_id = d['user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class PaymentSchedule(object):

    def __init__(self):
        self._date = None
        self._repaid_interest_total = None
        self._repaid_penalty_total = None
        self._repaid_principal_total = None
        self._start_date = None
        self._term = None
        self._unpaid_interest_total = None
        self._unpaid_penalty_total = None
        self._unpaid_principal_total = None

    @property
    def date(self):
        return self._date

    @date.setter
    def date(self, value):
        self._date = value
    @property
    def repaid_interest_total(self):
        return self._repaid_interest_total

    @repaid_interest_total.setter
    def repaid_interest_total(self, value):
        self._repaid_interest_total = value
    @property
    def repaid_penalty_total(self):
        return self._repaid_penalty_total

    @repaid_penalty_total.setter
    def repaid_penalty_total(self, value):
        self._repaid_penalty_total = value
    @property
    def repaid_principal_total(self):
        return self._repaid_principal_total

    @repaid_principal_total.setter
    def repaid_principal_total(self, value):
        self._repaid_principal_total = value
    @property
    def start_date(self):
        return self._start_date

    @start_date.setter
    def start_date(self, value):
        self._start_date = value
    @property
    def term(self):
        return self._term

    @term.setter
    def term(self, value):
        self._term = value
    @property
    def unpaid_interest_total(self):
        return self._unpaid_interest_total

    @unpaid_interest_total.setter
    def unpaid_interest_total(self, value):
        self._unpaid_interest_total = value
    @property
    def unpaid_penalty_total(self):
        return self._unpaid_penalty_total

    @unpaid_penalty_total.setter
    def unpaid_penalty_total(self, value):
        self._unpaid_penalty_total = value
    @property
    def unpaid_principal_total(self):
        return self._unpaid_principal_total

    @unpaid_principal_total.setter
    def unpaid_principal_total(self, value):
        self._unpaid_principal_total = value


    def to_alipay_dict(self):
        params = dict()
        if self.date:
            if hasattr(self.date, 'to_alipay_dict'):
                params['date'] = self.date.to_alipay_dict()
            else:
                params['date'] = self.date
        if self.repaid_interest_total:
            if hasattr(self.repaid_interest_total, 'to_alipay_dict'):
                params['repaid_interest_total'] = self.repaid_interest_total.to_alipay_dict()
            else:
                params['repaid_interest_total'] = self.repaid_interest_total
        if self.repaid_penalty_total:
            if hasattr(self.repaid_penalty_total, 'to_alipay_dict'):
                params['repaid_penalty_total'] = self.repaid_penalty_total.to_alipay_dict()
            else:
                params['repaid_penalty_total'] = self.repaid_penalty_total
        if self.repaid_principal_total:
            if hasattr(self.repaid_principal_total, 'to_alipay_dict'):
                params['repaid_principal_total'] = self.repaid_principal_total.to_alipay_dict()
            else:
                params['repaid_principal_total'] = self.repaid_principal_total
        if self.start_date:
            if hasattr(self.start_date, 'to_alipay_dict'):
                params['start_date'] = self.start_date.to_alipay_dict()
            else:
                params['start_date'] = self.start_date
        if self.term:
            if hasattr(self.term, 'to_alipay_dict'):
                params['term'] = self.term.to_alipay_dict()
            else:
                params['term'] = self.term
        if self.unpaid_interest_total:
            if hasattr(self.unpaid_interest_total, 'to_alipay_dict'):
                params['unpaid_interest_total'] = self.unpaid_interest_total.to_alipay_dict()
            else:
                params['unpaid_interest_total'] = self.unpaid_interest_total
        if self.unpaid_penalty_total:
            if hasattr(self.unpaid_penalty_total, 'to_alipay_dict'):
                params['unpaid_penalty_total'] = self.unpaid_penalty_total.to_alipay_dict()
            else:
                params['unpaid_penalty_total'] = self.unpaid_penalty_total
        if self.unpaid_principal_total:
            if hasattr(self.unpaid_principal_total, 'to_alipay_dict'):
                params['unpaid_principal_total'] = self.unpaid_principal_total.to_alipay_dict()
            else:
                params['unpaid_principal_total'] = self.unpaid_principal_total
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = PaymentSchedule()
        if 'date' in d:
            o.date = d['date']
        if 'repaid_interest_total' in d:
            o.repaid_interest_total = d['repaid_interest_total']
        if 'repaid_penalty_total' in d:
            o.repaid_penalty_total = d['repaid_penalty_total']
        if 'repaid_principal_total' in d:
            o.repaid_principal_total = d['repaid_principal_total']
        if 'start_date' in d:
            o.start_date = d['start_date']
        if 'term' in d:
            o.term = d['term']
        if 'unpaid_interest_total' in d:
            o.unpaid_interest_total = d['unpaid_interest_total']
        if 'unpaid_penalty_total' in d:
            o.unpaid_penalty_total = d['unpaid_penalty_total']
        if 'unpaid_principal_total' in d:
            o.unpaid_principal_total = d['unpaid_principal_total']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse


class AlipayOpenSearchBoxConsultResponse(AlipayResponse):

    def __init__(self):
        super(AlipayOpenSearchBoxConsultResponse, self).__init__()
        self._access = None
        self._not_pass_items = None

    @property
    def access(self):
        return self._access

    @access.setter
    def access(self, value):
        self._access = value
    @property
    def not_pass_items(self):
        return self._not_pass_items

    @not_pass_items.setter
    def not_pass_items(self, value):
        if isinstance(value, list):
            self._not_pass_items = list()
            for i in value:
                self._not_pass_items.append(i)

    def parse_response_content(self, response_content):
        response = super(AlipayOpenSearchBoxConsultResponse, self).parse_response_content(response_content)
        if 'access' in response:
            self.access = response['access']
        if 'not_pass_items' in response:
            self.not_pass_items = response['not_pass_items']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class IotDeliveryBaseInfo(object):

    def __init__(self):
        self._delivery_begin_time = None
        self._delivery_end_time = None
        self._delivery_name = None
        self._device_file_id = None
        self._device_file_url = None
        self._exclude_shop_ids = None
        self._include_shop_ids = None
        self._trade_down_threshold = None
        self._trade_upon_threshold = None

    @property
    def delivery_begin_time(self):
        return self._delivery_begin_time

    @delivery_begin_time.setter
    def delivery_begin_time(self, value):
        self._delivery_begin_time = value
    @property
    def delivery_end_time(self):
        return self._delivery_end_time

    @delivery_end_time.setter
    def delivery_end_time(self, value):
        self._delivery_end_time = value
    @property
    def delivery_name(self):
        return self._delivery_name

    @delivery_name.setter
    def delivery_name(self, value):
        self._delivery_name = value
    @property
    def device_file_id(self):
        return self._device_file_id

    @device_file_id.setter
    def device_file_id(self, value):
        self._device_file_id = value
    @property
    def device_file_url(self):
        return self._device_file_url

    @device_file_url.setter
    def device_file_url(self, value):
        self._device_file_url = value
    @property
    def exclude_shop_ids(self):
        return self._exclude_shop_ids

    @exclude_shop_ids.setter
    def exclude_shop_ids(self, value):
        self._exclude_shop_ids = value
    @property
    def include_shop_ids(self):
        return self._include_shop_ids

    @include_shop_ids.setter
    def include_shop_ids(self, value):
        self._include_shop_ids = value
    @property
    def trade_down_threshold(self):
        return self._trade_down_threshold

    @trade_down_threshold.setter
    def trade_down_threshold(self, value):
        self._trade_down_threshold = value
    @property
    def trade_upon_threshold(self):
        return self._trade_upon_threshold

    @trade_upon_threshold.setter
    def trade_upon_threshold(self, value):
        self._trade_upon_threshold = value


    def to_alipay_dict(self):
        params = dict()
        if self.delivery_begin_time:
            if hasattr(self.delivery_begin_time, 'to_alipay_dict'):
                params['delivery_begin_time'] = self.delivery_begin_time.to_alipay_dict()
            else:
                params['delivery_begin_time'] = self.delivery_begin_time
        if self.delivery_end_time:
            if hasattr(self.delivery_end_time, 'to_alipay_dict'):
                params['delivery_end_time'] = self.delivery_end_time.to_alipay_dict()
            else:
                params['delivery_end_time'] = self.delivery_end_time
        if self.delivery_name:
            if hasattr(self.delivery_name, 'to_alipay_dict'):
                params['delivery_name'] = self.delivery_name.to_alipay_dict()
            else:
                params['delivery_name'] = self.delivery_name
        if self.device_file_id:
            if hasattr(self.device_file_id, 'to_alipay_dict'):
                params['device_file_id'] = self.device_file_id.to_alipay_dict()
            else:
                params['device_file_id'] = self.device_file_id
        if self.device_file_url:
            if hasattr(self.device_file_url, 'to_alipay_dict'):
                params['device_file_url'] = self.device_file_url.to_alipay_dict()
            else:
                params['device_file_url'] = self.device_file_url
        if self.exclude_shop_ids:
            if hasattr(self.exclude_shop_ids, 'to_alipay_dict'):
                params['exclude_shop_ids'] = self.exclude_shop_ids.to_alipay_dict()
            else:
                params['exclude_shop_ids'] = self.exclude_shop_ids
        if self.include_shop_ids:
            if hasattr(self.include_shop_ids, 'to_alipay_dict'):
                params['include_shop_ids'] = self.include_shop_ids.to_alipay_dict()
            else:
                params['include_shop_ids'] = self.include_shop_ids
        if self.trade_down_threshold:
            if hasattr(self.trade_down_threshold, 'to_alipay_dict'):
                params['trade_down_threshold'] = self.trade_down_threshold.to_alipay_dict()
            else:
                params['trade_down_threshold'] = self.trade_down_threshold
        if self.trade_upon_threshold:
            if hasattr(self.trade_upon_threshold, 'to_alipay_dict'):
                params['trade_upon_threshold'] = self.trade_upon_threshold.to_alipay_dict()
            else:
                params['trade_upon_threshold'] = self.trade_upon_threshold
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = IotDeliveryBaseInfo()
        if 'delivery_begin_time' in d:
            o.delivery_begin_time = d['delivery_begin_time']
        if 'delivery_end_time' in d:
            o.delivery_end_time = d['delivery_end_time']
        if 'delivery_name' in d:
            o.delivery_name = d['delivery_name']
        if 'device_file_id' in d:
            o.device_file_id = d['device_file_id']
        if 'device_file_url' in d:
            o.device_file_url = d['device_file_url']
        if 'exclude_shop_ids' in d:
            o.exclude_shop_ids = d['exclude_shop_ids']
        if 'include_shop_ids' in d:
            o.include_shop_ids = d['include_shop_ids']
        if 'trade_down_threshold' in d:
            o.trade_down_threshold = d['trade_down_threshold']
        if 'trade_upon_threshold' in d:
            o.trade_upon_threshold = d['trade_upon_threshold']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.response.AlipayResponse import AlipayResponse
from alipay.aop.api.domain.UserRiskPrediction import UserRiskPrediction
from alipay.aop.api.domain.WaitRepaymentOrderInfo import WaitRepaymentOrderInfo


class AlipayTradeAdvanceConsultResponse(AlipayResponse):

    def __init__(self):
        super(AlipayTradeAdvanceConsultResponse, self).__init__()
        self._refer_result = None
        self._result_code = None
        self._result_message = None
        self._risk_level = None
        self._user_risk_prediction = None
        self._wait_repayment_amount = None
        self._wait_repayment_order_count = None
        self._wait_repayment_order_infos = None

    @property
    def refer_result(self):
        return self._refer_result

    @refer_result.setter
    def refer_result(self, value):
        self._refer_result = value
    @property
    def result_code(self):
        return self._result_code

    @result_code.setter
    def result_code(self, value):
        self._result_code = value
    @property
    def result_message(self):
        return self._result_message

    @result_message.setter
    def result_message(self, value):
        self._result_message = value
    @property
    def risk_level(self):
        return self._risk_level

    @risk_level.setter
    def risk_level(self, value):
        self._risk_level = value
    @property
    def user_risk_prediction(self):
        return self._user_risk_prediction

    @user_risk_prediction.setter
    def user_risk_prediction(self, value):
        if isinstance(value, UserRiskPrediction):
            self._user_risk_prediction = value
        else:
            self._user_risk_prediction = UserRiskPrediction.from_alipay_dict(value)
    @property
    def wait_repayment_amount(self):
        return self._wait_repayment_amount

    @wait_repayment_amount.setter
    def wait_repayment_amount(self, value):
        self._wait_repayment_amount = value
    @property
    def wait_repayment_order_count(self):
        return self._wait_repayment_order_count

    @wait_repayment_order_count.setter
    def wait_repayment_order_count(self, value):
        self._wait_repayment_order_count = value
    @property
    def wait_repayment_order_infos(self):
        return self._wait_repayment_order_infos

    @wait_repayment_order_infos.setter
    def wait_repayment_order_infos(self, value):
        if isinstance(value, list):
            self._wait_repayment_order_infos = list()
            for i in value:
                if isinstance(i, WaitRepaymentOrderInfo):
                    self._wait_repayment_order_infos.append(i)
                else:
                    self._wait_repayment_order_infos.append(WaitRepaymentOrderInfo.from_alipay_dict(i))

    def parse_response_content(self, response_content):
        response = super(AlipayTradeAdvanceConsultResponse, self).parse_response_content(response_content)
        if 'refer_result' in response:
            self.refer_result = response['refer_result']
        if 'result_code' in response:
            self.result_code = response['result_code']
        if 'result_message' in response:
            self.result_message = response['result_message']
        if 'risk_level' in response:
            self.risk_level = response['risk_level']
        if 'user_risk_prediction' in response:
            self.user_risk_prediction = response['user_risk_prediction']
        if 'wait_repayment_amount' in response:
            self.wait_repayment_amount = response['wait_repayment_amount']
        if 'wait_repayment_order_count' in response:
            self.wait_repayment_order_count = response['wait_repayment_order_count']
        if 'wait_repayment_order_infos' in response:
            self.wait_repayment_order_infos = response['wait_repayment_order_infos']



#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenMiniInnerversionTemplatebasedUploadModel(object):

    def __init__(self):
        self._app_version = None
        self._build_extra_info = None
        self._build_type = None
        self._bundle_id = None
        self._inst_code = None
        self._mini_app_id = None
        self._template_bundle_id = None
        self._template_id = None
        self._template_version = None
        self._version_status = None

    @property
    def app_version(self):
        return self._app_version

    @app_version.setter
    def app_version(self, value):
        self._app_version = value
    @property
    def build_extra_info(self):
        return self._build_extra_info

    @build_extra_info.setter
    def build_extra_info(self, value):
        self._build_extra_info = value
    @property
    def build_type(self):
        return self._build_type

    @build_type.setter
    def build_type(self, value):
        self._build_type = value
    @property
    def bundle_id(self):
        return self._bundle_id

    @bundle_id.setter
    def bundle_id(self, value):
        self._bundle_id = value
    @property
    def inst_code(self):
        return self._inst_code

    @inst_code.setter
    def inst_code(self, value):
        self._inst_code = value
    @property
    def mini_app_id(self):
        return self._mini_app_id

    @mini_app_id.setter
    def mini_app_id(self, value):
        self._mini_app_id = value
    @property
    def template_bundle_id(self):
        return self._template_bundle_id

    @template_bundle_id.setter
    def template_bundle_id(self, value):
        self._template_bundle_id = value
    @property
    def template_id(self):
        return self._template_id

    @template_id.setter
    def template_id(self, value):
        self._template_id = value
    @property
    def template_version(self):
        return self._template_version

    @template_version.setter
    def template_version(self, value):
        self._template_version = value
    @property
    def version_status(self):
        return self._version_status

    @version_status.setter
    def version_status(self, value):
        self._version_status = value


    def to_alipay_dict(self):
        params = dict()
        if self.app_version:
            if hasattr(self.app_version, 'to_alipay_dict'):
                params['app_version'] = self.app_version.to_alipay_dict()
            else:
                params['app_version'] = self.app_version
        if self.build_extra_info:
            if hasattr(self.build_extra_info, 'to_alipay_dict'):
                params['build_extra_info'] = self.build_extra_info.to_alipay_dict()
            else:
                params['build_extra_info'] = self.build_extra_info
        if self.build_type:
            if hasattr(self.build_type, 'to_alipay_dict'):
                params['build_type'] = self.build_type.to_alipay_dict()
            else:
                params['build_type'] = self.build_type
        if self.bundle_id:
            if hasattr(self.bundle_id, 'to_alipay_dict'):
                params['bundle_id'] = self.bundle_id.to_alipay_dict()
            else:
                params['bundle_id'] = self.bundle_id
        if self.inst_code:
            if hasattr(self.inst_code, 'to_alipay_dict'):
                params['inst_code'] = self.inst_code.to_alipay_dict()
            else:
                params['inst_code'] = self.inst_code
        if self.mini_app_id:
            if hasattr(self.mini_app_id, 'to_alipay_dict'):
                params['mini_app_id'] = self.mini_app_id.to_alipay_dict()
            else:
                params['mini_app_id'] = self.mini_app_id
        if self.template_bundle_id:
            if hasattr(self.template_bundle_id, 'to_alipay_dict'):
                params['template_bundle_id'] = self.template_bundle_id.to_alipay_dict()
            else:
                params['template_bundle_id'] = self.template_bundle_id
        if self.template_id:
            if hasattr(self.template_id, 'to_alipay_dict'):
                params['template_id'] = self.template_id.to_alipay_dict()
            else:
                params['template_id'] = self.template_id
        if self.template_version:
            if hasattr(self.template_version, 'to_alipay_dict'):
                params['template_version'] = self.template_version.to_alipay_dict()
            else:
                params['template_version'] = self.template_version
        if self.version_status:
            if hasattr(self.version_status, 'to_alipay_dict'):
                params['version_status'] = self.version_status.to_alipay_dict()
            else:
                params['version_status'] = self.version_status
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenMiniInnerversionTemplatebasedUploadModel()
        if 'app_version' in d:
            o.app_version = d['app_version']
        if 'build_extra_info' in d:
            o.build_extra_info = d['build_extra_info']
        if 'build_type' in d:
            o.build_type = d['build_type']
        if 'bundle_id' in d:
            o.bundle_id = d['bundle_id']
        if 'inst_code' in d:
            o.inst_code = d['inst_code']
        if 'mini_app_id' in d:
            o.mini_app_id = d['mini_app_id']
        if 'template_bundle_id' in d:
            o.template_bundle_id = d['template_bundle_id']
        if 'template_id' in d:
            o.template_id = d['template_id']
        if 'template_version' in d:
            o.template_version = d['template_version']
        if 'version_status' in d:
            o.version_status = d['version_status']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayEbppCommunityChargeproductModifyModel(object):

    def __init__(self):
        self._community_short_name = None
        self._maintaining_end = None
        self._maintaining_start = None

    @property
    def community_short_name(self):
        return self._community_short_name

    @community_short_name.setter
    def community_short_name(self, value):
        self._community_short_name = value
    @property
    def maintaining_end(self):
        return self._maintaining_end

    @maintaining_end.setter
    def maintaining_end(self, value):
        self._maintaining_end = value
    @property
    def maintaining_start(self):
        return self._maintaining_start

    @maintaining_start.setter
    def maintaining_start(self, value):
        self._maintaining_start = value


    def to_alipay_dict(self):
        params = dict()
        if self.community_short_name:
            if hasattr(self.community_short_name, 'to_alipay_dict'):
                params['community_short_name'] = self.community_short_name.to_alipay_dict()
            else:
                params['community_short_name'] = self.community_short_name
        if self.maintaining_end:
            if hasattr(self.maintaining_end, 'to_alipay_dict'):
                params['maintaining_end'] = self.maintaining_end.to_alipay_dict()
            else:
                params['maintaining_end'] = self.maintaining_end
        if self.maintaining_start:
            if hasattr(self.maintaining_start, 'to_alipay_dict'):
                params['maintaining_start'] = self.maintaining_start.to_alipay_dict()
            else:
                params['maintaining_start'] = self.maintaining_start
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayEbppCommunityChargeproductModifyModel()
        if 'community_short_name' in d:
            o.community_short_name = d['community_short_name']
        if 'maintaining_end' in d:
            o.maintaining_end = d['maintaining_end']
        if 'maintaining_start' in d:
            o.maintaining_start = d['maintaining_start']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class MybankCreditSceneprodDiscountplanQueryModel(object):

    def __init__(self):
        self._org_code = None
        self._site = None
        self._site_user_id = None

    @property
    def org_code(self):
        return self._org_code

    @org_code.setter
    def org_code(self, value):
        self._org_code = value
    @property
    def site(self):
        return self._site

    @site.setter
    def site(self, value):
        self._site = value
    @property
    def site_user_id(self):
        return self._site_user_id

    @site_user_id.setter
    def site_user_id(self, value):
        self._site_user_id = value


    def to_alipay_dict(self):
        params = dict()
        if self.org_code:
            if hasattr(self.org_code, 'to_alipay_dict'):
                params['org_code'] = self.org_code.to_alipay_dict()
            else:
                params['org_code'] = self.org_code
        if self.site:
            if hasattr(self.site, 'to_alipay_dict'):
                params['site'] = self.site.to_alipay_dict()
            else:
                params['site'] = self.site
        if self.site_user_id:
            if hasattr(self.site_user_id, 'to_alipay_dict'):
                params['site_user_id'] = self.site_user_id.to_alipay_dict()
            else:
                params['site_user_id'] = self.site_user_id
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = MybankCreditSceneprodDiscountplanQueryModel()
        if 'org_code' in d:
            o.org_code = d['org_code']
        if 'site' in d:
            o.site = d['site']
        if 'site_user_id' in d:
            o.site_user_id = d['site_user_id']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class SignfieldInfoDTO(object):

    def __init__(self):
        self._file_id = None
        self._free_sign = None
        self._pos_page = None
        self._pos_page_end = None
        self._pos_x = None
        self._pos_y = None
        self._position_type = None
        self._sign_area_type = None

    @property
    def file_id(self):
        return self._file_id

    @file_id.setter
    def file_id(self, value):
        self._file_id = value
    @property
    def free_sign(self):
        return self._free_sign

    @free_sign.setter
    def free_sign(self, value):
        self._free_sign = value
    @property
    def pos_page(self):
        return self._pos_page

    @pos_page.setter
    def pos_page(self, value):
        self._pos_page = value
    @property
    def pos_page_end(self):
        return self._pos_page_end

    @pos_page_end.setter
    def pos_page_end(self, value):
        self._pos_page_end = value
    @property
    def pos_x(self):
        return self._pos_x

    @pos_x.setter
    def pos_x(self, value):
        self._pos_x = value
    @property
    def pos_y(self):
        return self._pos_y

    @pos_y.setter
    def pos_y(self, value):
        self._pos_y = value
    @property
    def position_type(self):
        return self._position_type

    @position_type.setter
    def position_type(self, value):
        self._position_type = value
    @property
    def sign_area_type(self):
        return self._sign_area_type

    @sign_area_type.setter
    def sign_area_type(self, value):
        self._sign_area_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.file_id:
            if hasattr(self.file_id, 'to_alipay_dict'):
                params['file_id'] = self.file_id.to_alipay_dict()
            else:
                params['file_id'] = self.file_id
        if self.free_sign:
            if hasattr(self.free_sign, 'to_alipay_dict'):
                params['free_sign'] = self.free_sign.to_alipay_dict()
            else:
                params['free_sign'] = self.free_sign
        if self.pos_page:
            if hasattr(self.pos_page, 'to_alipay_dict'):
                params['pos_page'] = self.pos_page.to_alipay_dict()
            else:
                params['pos_page'] = self.pos_page
        if self.pos_page_end:
            if hasattr(self.pos_page_end, 'to_alipay_dict'):
                params['pos_page_end'] = self.pos_page_end.to_alipay_dict()
            else:
                params['pos_page_end'] = self.pos_page_end
        if self.pos_x:
            if hasattr(self.pos_x, 'to_alipay_dict'):
                params['pos_x'] = self.pos_x.to_alipay_dict()
            else:
                params['pos_x'] = self.pos_x
        if self.pos_y:
            if hasattr(self.pos_y, 'to_alipay_dict'):
                params['pos_y'] = self.pos_y.to_alipay_dict()
            else:
                params['pos_y'] = self.pos_y
        if self.position_type:
            if hasattr(self.position_type, 'to_alipay_dict'):
                params['position_type'] = self.position_type.to_alipay_dict()
            else:
                params['position_type'] = self.position_type
        if self.sign_area_type:
            if hasattr(self.sign_area_type, 'to_alipay_dict'):
                params['sign_area_type'] = self.sign_area_type.to_alipay_dict()
            else:
                params['sign_area_type'] = self.sign_area_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = SignfieldInfoDTO()
        if 'file_id' in d:
            o.file_id = d['file_id']
        if 'free_sign' in d:
            o.free_sign = d['free_sign']
        if 'pos_page' in d:
            o.pos_page = d['pos_page']
        if 'pos_page_end' in d:
            o.pos_page_end = d['pos_page_end']
        if 'pos_x' in d:
            o.pos_x = d['pos_x']
        if 'pos_y' in d:
            o.pos_y = d['pos_y']
        if 'position_type' in d:
            o.position_type = d['position_type']
        if 'sign_area_type' in d:
            o.sign_area_type = d['sign_area_type']
        return o





#!/usr/bin/env python
# -*- coding: utf-8 -*-
import json

from alipay.aop.api.constant.ParamConstants import *


class AlipayOpenMiniCloudSupportModifyModel(object):

    def __init__(self):
        self._mini_app_id = None
        self._operate_type = None
        self._service_type = None

    @property
    def mini_app_id(self):
        return self._mini_app_id

    @mini_app_id.setter
    def mini_app_id(self, value):
        self._mini_app_id = value
    @property
    def operate_type(self):
        return self._operate_type

    @operate_type.setter
    def operate_type(self, value):
        self._operate_type = value
    @property
    def service_type(self):
        return self._service_type

    @service_type.setter
    def service_type(self, value):
        self._service_type = value


    def to_alipay_dict(self):
        params = dict()
        if self.mini_app_id:
            if hasattr(self.mini_app_id, 'to_alipay_dict'):
                params['mini_app_id'] = self.mini_app_id.to_alipay_dict()
            else:
                params['mini_app_id'] = self.mini_app_id
        if self.operate_type:
            if hasattr(self.operate_type, 'to_alipay_dict'):
                params['operate_type'] = self.operate_type.to_alipay_dict()
            else:
                params['operate_type'] = self.operate_type
        if self.service_type:
            if hasattr(self.service_type, 'to_alipay_dict'):
                params['service_type'] = self.service_type.to_alipay_dict()
            else:
                params['service_type'] = self.service_type
        return params

    @staticmethod
    def from_alipay_dict(d):
        if not d:
            return None
        o = AlipayOpenMiniCloudSupportModifyModel()
        if 'mini_app_id' in d:
            o.mini_app_id = d['mini_app_id']
        if 'operate_type' in d:
            o.operate_type = d['operate_type']
        if 'service_type' in d:
            o.service_type = d['service_type']
        return o


